"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QSysInfo(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsysinfo.html

    **Detailed Description**

    * **WordSize**  specifies the size of a pointer for the platform on which
    the application is compiled.
      * **ByteOrder**  specifies whether the
    platform is big-endian or little-endian.

    Some constants are defined only on certain platforms. You can use the
    preprocessor symbols **Q_OS_WIN**  and **Q_OS_MACOS**  to test that the
    application is compiled under Windows or macOS.

    **See also** **QLibraryInfo** .
    """

    class Endian(enum.Enum):
        BigEndian: QSysInfo = ...
        LittleEndian: QSysInfo = ...
        ByteOrder: QSysInfo = ...

    class Sizes(enum.Enum):
        WordSize: QSysInfo = ...

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QSysInfo") -> None:
        ...

    @staticmethod
    def bootUniqueId() -> QByteArray:
        """
        https://doc.qt.io/qt-6/qsysinfo.html#bootUniqueId

        **[static, since 5.11] QByteArray QSysInfo::bootUniqueId()**

        Returns a unique ID for this machine's boot, if one can be determined.
        If no unique ID could be determined, this function returns an empty byte
        array. This value is expected to change after every boot and can be
        considered globally unique.

        This function is currently only implemented for Linux and Apple
        operating systems.

        This function was introduced in Qt 5.11.

        **See also** **machineUniqueId** ().
        """
        ...

    @staticmethod
    def machineUniqueId() -> QByteArray:
        """
        https://doc.qt.io/qt-6/qsysinfo.html#machineUniqueId

        **[static, since 5.11] QByteArray QSysInfo::machineUniqueId()**

        Returns a unique ID for this machine, if one can be determined. If no
        unique ID could be determined, this function returns an empty byte
        array. Unlike **machineHostName** (), the value returned by this
        function is likely globally unique.

        A unique ID is useful in network operations to identify this machine for
        an extended period of time, when the IP address could change or if this
        machine could have more than one IP address. For example, the ID could
        be used when communicating with a server or when storing device-specific
        data in shared network storage.

        Note that on some systems, this value will persist across reboots and on
        some it will not. Applications should not blindly depend on this fact
        without verifying the OS capabilities. In particular, on Linux systems,
        this ID is usually permanent and it matches the D-Bus machine ID, except
        for nodes without their own storage (replicated nodes).

        This function was introduced in Qt 5.11.

        **See also** **machineHostName** () and **bootUniqueId** ().
        """
        ...

    @staticmethod
    def machineHostName() -> str:
        """
        https://doc.qt.io/qt-6/qsysinfo.html#machineHostName

        **[static, since 5.6] QString QSysInfo::machineHostName()**

        Returns this machine's host name, if one is configured. Note that
        hostnames are not guaranteed to be globally unique, especially if they
        were configured automatically.

        This function does not guarantee the returned host name is a Fully
        Qualified Domain Name (FQDN). For that, use **QHostInfo**  to resolve
        the returned name to an FQDN.

        This function returns the same as **QHostInfo::localHostName** ().

        This function was introduced in Qt 5.6.

        **See also** **QHostInfo::localDomainName**  and **machineUniqueId** ().
        """
        ...

    @staticmethod
    def prettyProductName() -> str:
        """
        https://doc.qt.io/qt-6/qsysinfo.html#prettyProductName

        **[static, since 5.4] QString QSysInfo::prettyProductName()**

        Returns a prettier form of **productType** () and **productVersion** (),
        containing other tokens like the operating system type, codenames and
        other information. The result of this function is suitable for
        displaying to the user, but not for long-term storage, as the string may
        change with updates to Qt.

        If **productType** () is "unknown", this function will instead use the
        **kernelType** () and **kernelVersion** () functions.

        This function was introduced in Qt 5.4.

        **See also** **kernelType** (), **kernelVersion** (), **productType**
        (), and **productVersion** ().
        """
        ...

    @staticmethod
    def productVersion() -> str:
        """
        https://doc.qt.io/qt-6/qsysinfo.html#productVersion

        **[static, since 5.4] QString QSysInfo::productVersion()**

        Returns the product version of the operating system in string form. If
        the version could not be determined, this function returns "unknown".

        It will return the Android, iOS, macOS, Windows full-product versions on
        those systems.

        Typical returned values are (note: list not exhaustive):

        * "2016.09" (Amazon Linux AMI 2016.09)
          * "7.1" (Android Nougat)
          *
        "25" (Fedora 25)
          * "10.1" (iOS 10.1)
          * "10.12" (macOS Sierra)
          *
        "10.0" (tvOS 10)
          * "16.10" (Ubuntu 16.10)
          * "3.1" (watchOS 3.1)
          *
        "10" (Windows 10)
          * "Server 2016" (Windows Server 2016)

        On Linux systems, it will try to determine the distribution version and
        will return that. This is also done on Debian/kFreeBSD, so this function
        will return Debian version in that case.

        In all other Unix-type systems, this function always returns "unknown".

        **Note:** The version string returned from this function is not
        guaranteed to be orderable. On Linux, the version of the distribution
        may jump unexpectedly, please refer to the distribution's documentation
        for versioning practices.

        This function was introduced in Qt 5.4.

        **See also** **kernelType** (), **kernelVersion** (), **productType**
        (), and **prettyProductName** ().
        """
        ...

    @staticmethod
    def productType() -> str:
        """
        https://doc.qt.io/qt-6/qsysinfo.html#productType

        **[static, since 5.4] QString QSysInfo::productType()**

        Returns the product name of the operating system this application is
        running in. If the application is running on some sort of emulation or
        virtualization layer (such as WINE on a Unix system), this function will
        inspect the emulation / virtualization layer.

        Values returned by this function are stable and will not change over
        time, so applications can rely on the returned value as an identifier,
        except that new OS types may be added over time.

        **Linux and Android note** : this function returns "android" for Linux
        systems running Android userspace, notably when using the Bionic
        library. For all other Linux systems, regardless of C library being
        used, it tries to determine the distribution name and returns that. If
        determining the distribution name failed, it returns "unknown".

        **macOS note** : this function returns "osx" for all macOS systems,
        regardless of Apple naming convention. The returned string will be
        updated for Qt 6. Note that this function erroneously returned "macos"
        for macOS 10.12 in Qt versions 5.6.2, 5.7.1, and 5.8.0.

        **Darwin, iOS, tvOS, and watchOS note** : this function returns "ios"
        for iOS systems, "tvos" for tvOS systems, "watchos" for watchOS systems,
        and "darwin" in case the system could not be determined.

        **FreeBSD note** : this function returns "debian" for Debian/kFreeBSD
        and "unknown" otherwise.

        **Windows note** : this function return "windows"

        For other Unix-type systems, this function usually returns "unknown".

        This function was introduced in Qt 5.4.

        **See also** **QFileSelector** , **kernelType** (), **kernelVersion**
        (), **productVersion** (), and **prettyProductName** ().
        """
        ...

    @staticmethod
    def kernelVersion() -> str:
        """
        https://doc.qt.io/qt-6/qsysinfo.html#kernelVersion

        **[static, since 5.4] QString QSysInfo::kernelVersion()**

        Returns the release version of the operating system kernel. On Windows,
        it returns the version of the NT kernel. On Unix systems, including
        Android and macOS, it returns the same as the `uname -r` command would
        return.

        If the version could not be determined, this function may return an
        empty string.

        This function was introduced in Qt 5.4.

        **See also** **kernelType** (), **productType** (), **productVersion**
        (), and **prettyProductName** ().
        """
        ...

    @staticmethod
    def kernelType() -> str:
        """
        https://doc.qt.io/qt-6/qsysinfo.html#kernelType

        **[static, since 5.4] QString QSysInfo::kernelType()**

        Returns the type of the operating system kernel Qt was compiled for.
        It's also the kernel the application is running on, unless the host
        operating system is running a form of compatibility or virtualization
        layer.

        Values returned by this function are stable and will not change over
        time, so applications can rely on the returned value as an identifier,
        except that new OS kernel types may be added over time.

        On Windows, this function returns the type of Windows kernel, like
        "winnt". On Unix systems, it returns the same as the output of `uname
        -s` (lowercased).

        **Note:** This function may return surprising values: it returns "linux"
        for all operating systems running Linux (including Android), "qnx" for
        all operating systems running QNX, "freebsd" for Debian/kFreeBSD, and
        "darwin" for macOS and iOS. For information on the type of product the
        application is running on, see **productType** ().

        This function was introduced in Qt 5.4.

        **See also** **QFileSelector** , **kernelVersion** (), **productType**
        (), **productVersion** (), and **prettyProductName** ().
        """
        ...

    @staticmethod
    def buildAbi() -> str:
        """
        https://doc.qt.io/qt-6/qsysinfo.html#buildAbi

        **[static, since 5.4] QString QSysInfo::buildAbi()**

        Returns the full architecture string that Qt was compiled for. This
        string is useful for identifying different, incompatible builds. For
        example, it can be used as an identifier to request an upgrade package
        from a server.

        The values returned from this function are kept stable as follows: the
        mandatory components of the result will not change in future versions of
        Qt, but optional suffixes may be added.

        The returned value is composed of three or more parts, separated by
        dashes ("-"). They are:

        ComponentValue
        CPU ArchitectureThe same as
        **QSysInfo::buildCpuArchitecture** (), such as "arm", "i386", "mips" or
        "x86_64"
        Endianness"little_endian" or "big_endian"
        Word sizeWhether
        it's a 32- or 64-bit application. Possible values are: "llp64" (Windows
        64-bit), "lp64" (Unix 64-bit), "ilp32" (32-bit)
        (Optional) ABIZero or
        more components identifying different ABIs possible in this
        architecture. Currently, Qt has optional ABI components for ARM and MIPS
        processors: one component is the main ABI (such as "eabi", "o32", "n32",
        "o64"); another is whether the calling convention is using hardware
        floating point registers ("hardfloat" is present).

        Additionally, if Qt
        was configured with `-qreal float`, the ABI option tag "qreal_float"
        will be present. If Qt was configured with another type as qreal, that
        type is present after "qreal_", with all characters other than letters
        and digits escaped by an underscore, followed by two hex digits. For
        example, `-qreal long double` becomes "qreal_long_20double".

        This function was introduced in Qt 5.4.

        **See also** **QSysInfo::buildCpuArchitecture** ().
        """
        ...

    @staticmethod
    def currentCpuArchitecture() -> str:
        """
        https://doc.qt.io/qt-6/qsysinfo.html#currentCpuArchitecture

        **[static, since 5.4] QString QSysInfo::currentCpuArchitecture()**

        Returns the architecture of the CPU that the application is running on,
        in text format. Note that this function depends on what the OS will
        report and may not detect the actual CPU architecture if the OS hides
        that information or is unable to provide it. For example, a 32-bit OS
        running on a 64-bit CPU is usually unable to determine the CPU is
        actually capable of running 64-bit programs.

        Values returned by this function are mostly stable: an attempt will be
        made to ensure that they stay constant over time and match the values
        returned by QSysInfo::builldCpuArchitecture(). However, due to the
        nature of the operating system functions being used, there may be
        discrepancies.

        Typical returned values are (note: list not exhaustive):

        * "arm"
          * "arm64"
          * "i386"
          * "ia64"
          * "mips"
          * "mips64"
          *
        "power"
          * "power64"
          * "sparc"
          * "sparcv9"
          * "x86_64"

        This function was introduced in Qt 5.4.

        **See also** **QSysInfo::buildAbi** () and
        **QSysInfo::buildCpuArchitecture** ().
        """
        ...

    @staticmethod
    def buildCpuArchitecture() -> str:
        """
        https://doc.qt.io/qt-6/qsysinfo.html#buildCpuArchitecture

        **[static, since 5.4] QString QSysInfo::buildCpuArchitecture()**

        Returns the architecture of the CPU that Qt was compiled for, in text
        format. Note that this may not match the actual CPU that the application
        is running on if there's an emulation layer or if the CPU supports
        multiple architectures (like x86-64 processors supporting i386
        applications). To detect that, use **currentCpuArchitecture** ().

        Values returned by this function are stable and will not change over
        time, so applications can rely on the returned value as an identifier,
        except that new CPU types may be added over time.

        Typical returned values are (note: list not exhaustive):

        * "arm"
          * "arm64"
          * "i386"
          * "ia64"
          * "mips"
          * "mips64"
          *
        "power"
          * "power64"
          * "sparc"
          * "sparcv9"
          * "x86_64"

        This function was introduced in Qt 5.4.

        **See also** **QSysInfo::buildAbi** () and
        **QSysInfo::currentCpuArchitecture** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtQml import *


class QQmlExpression(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qqmlexpression.html

    **Detailed Description**

    For example, given a file `main.qml` like this:

    import QtQuick 2.0

        **Item**  {
            width: 200; height: 200
    }

    The following code evaluates a JavaScript expression in the context of the
    above QML:

    **QQmlEngine**  *engine = new **QQmlEngine** ;
        **QQmlComponent**
    component(engine, **QUrl** ::fromLocalFile("main.qml"));
    **QObject**  *myObject = component.create();
        **QQmlExpression**  *expr =
    new **QQmlExpression** (engine->rootContext(), myObject, "width * 2");
    int result = expr->evaluate().toInt();  // result = 400
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#QQmlExpression

        **QQmlExpression::QQmlExpression()**

        Create an invalid QQmlExpression.

        As the expression will not have an associated **QQmlContext** , this
        will be a null expression object and its value will always be an invalid
        **QVariant** .
        """
        ...

    @typing.overload
    def __init__(
        self,
        a0: QQmlContext,
        a1: QtCore.QObject,
        a2: str,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#QQmlExpression-1

        **QQmlExpression::QQmlExpression(QQmlContext * ctxt , QObject * scope ,
        const QString & expression , QObject * parent = nullptr)**

        Create a QQmlExpression object that is a child of **parent**.

        The **expression** JavaScript will be executed in the **ctxt**
        **QQmlContext** . If specified, the **scope** object's properties will
        also be in scope during the expression's execution.
        """
        ...

    @typing.overload
    def __init__(
        self,
        a0: "QQmlScriptString",
        context: typing.Optional[QQmlContext] = ...,
        scope: typing.Optional[QtCore.QObject] = ...,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#QQmlExpression-2

        **QQmlExpression::QQmlExpression(const QQmlScriptString & script ,
        QQmlContext * ctxt = nullptr, QObject * scope = nullptr, QObject *
        parent = nullptr)**

        Create a QQmlExpression object that is a child of **parent**.

        The **script** provides the expression to be evaluated, the context to
        evaluate it in, and the scope object to evaluate it with. If provided,
        **ctxt** and **scope** will override the context and scope object
        provided by **script**.

        **See also** **QQmlScriptString** .
        """
        ...

    def evaluate(self) -> typing.Tuple[typing.Any, bool]:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#evaluate

        **QVariant QQmlExpression::evaluate(bool * valueIsUndefined = nullptr)**

        Evaulates the expression, returning the result of the evaluation, or an
        invalid **QVariant**  if the expression is invalid or has an error.

        **valueIsUndefined** is set to true if the expression resulted in an
        undefined value.

        **See also** **hasError** () and **error** ().
        """
        ...

    def error(self) -> QQmlError:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#error

        **QQmlError QQmlExpression::error() const**

        Return any error from the last call to **evaluate** (). If there was no
        error, this returns an invalid **QQmlError**  instance.

        **See also** **hasError** () and **clearError** ().
        """
        ...

    def clearError(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#clearError

        **void QQmlExpression::clearError()**

        Clear any expression errors. Calls to **hasError** () following this
        will return false.

        **See also** **hasError** () and **error** ().
        """
        ...

    def hasError(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#hasError

        **bool QQmlExpression::hasError() const**

        Returns true if the last call to **evaluate** () resulted in an error,
        otherwise false.

        **See also** **error** () and **clearError** ().
        """
        ...

    def scopeObject(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#scopeObject

        **QObject *QQmlExpression::scopeObject() const**

        Returns the expression's scope object, if provided, otherwise 0.

        In addition to data provided by the expression's **QQmlContext** , the
        scope object's properties are also in scope during the expression's
        evaluation.
        """
        ...

    def setSourceLocation(self, fileName: str, line: int, column: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#setSourceLocation

        **void QQmlExpression::setSourceLocation(const QString & url , int line
        , int column = 0)**

        Set the location of this expression to **line** and **column** of
        **url**. This information is used by the script engine.
        """
        ...

    def columnNumber(self) -> int:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#columnNumber

        **int QQmlExpression::columnNumber() const**

        Returns the source file column number for this expression. The source
        location must have been previously set by calling **setSourceLocation**
        ().
        """
        ...

    def lineNumber(self) -> int:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#lineNumber

        **int QQmlExpression::lineNumber() const**

        Returns the source file line number for this expression. The source
        location must have been previously set by calling **setSourceLocation**
        ().
        """
        ...

    def sourceFile(self) -> str:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#sourceFile

        **QString QQmlExpression::sourceFile() const**

        Returns the source file URL for this expression. The source location
        must have been previously set by calling **setSourceLocation** ().
        """
        ...

    def setNotifyOnValueChanged(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#setNotifyOnValueChanged

        **void QQmlExpression::setNotifyOnValueChanged(bool notifyOnChange )**

        Sets whether the **valueChanged** () signal is emitted when the
        expression's evaluated value changes.

        If **notifyOnChange** is true, the **QQmlExpression**  will monitor
        properties involved in the expression's evaluation, and emit
        **QQmlExpression::valueChanged** () if they have changed. This allows an
        application to ensure that any value associated with the result of the
        expression remains up to date.

        If **notifyOnChange** is false (default), the **QQmlExpression**  will
        not montitor properties involved in the expression's evaluation, and
        **QQmlExpression::valueChanged** () will never be emitted. This is more
        efficient if an application wants a "one off" evaluation of the
        expression.

        **See also** **notifyOnValueChanged** ().
        """
        ...

    def notifyOnValueChanged(self) -> bool:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#notifyOnValueChanged

        **bool QQmlExpression::notifyOnValueChanged() const**

        Returns true if the **valueChanged** () signal is emitted when the
        expression's evaluated value changes.

        **See also** **setNotifyOnValueChanged** ().
        """
        ...

    def setExpression(self, a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#setExpression

        **void QQmlExpression::setExpression(const QString & expression )**

        Set the expression to **expression**.

        **See also** **expression** ().
        """
        ...

    def expression(self) -> str:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#expression

        **QString QQmlExpression::expression() const**

        Returns the expression string.

        **See also** **setExpression** ().
        """
        ...

    def context(self) -> QQmlContext:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#context

        **QQmlContext *QQmlExpression::context() const**

        Returns the **QQmlContext**  this expression is associated with, or
        `nullptr` if there is no association or the **QQmlContext**  has been
        destroyed.
        """
        ...

    def engine(self) -> QQmlEngine:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#engine

        **QQmlEngine *QQmlExpression::engine() const**

        Returns the **QQmlEngine**  this expression is associated with, or
        `nullptr` if there is no association or the **QQmlEngine**  has been
        destroyed.
        """
        ...

    @property
    def valueChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qqmlexpression.html#valueChanged

        **[signal] void QQmlExpression::valueChanged()**

        Emitted each time the expression value changes from the last time it was
        evaluated. The expression must have been evaluated at least once (by
        calling **QQmlExpression::evaluate** ()) before this signal will be
        emitted.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
import datetime
from PyQt6.QtCore import *


class QTime(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtime.html

    **Detailed Description**

    A QTime object contains a clock time, which it can express as the numbers of
    hours, minutes, seconds, and milliseconds since midnight. It provides
    functions for comparing times and for manipulating a time by adding a number
    of milliseconds. QTime objects should be passed by value rather than by
    reference to const; they simply package `int`.

    QTime uses the 24-hour clock format; it has no concept of AM/PM. Unlike
    **QDateTime** , QTime knows nothing about time zones or daylight-saving time
    (DST).

    A QTime object is typically created either by giving the number of hours,
    minutes, seconds, and milliseconds explicitly, or by using the static
    function **currentTime** (), which creates a QTime object that represents
    the system's local time.

    The **hour** (), **minute** (), **second** (), and **msec** () functions
    provide access to the number of hours, minutes, seconds, and milliseconds of
    the time. The same information is provided in textual format by the
    **toString** () function.

    The **addSecs** () and **addMSecs** () functions provide the time a given
    number of seconds or milliseconds later than a given time. Correspondingly,
    the number of seconds or milliseconds between two times can be found using
    **secsTo** () or **msecsTo** ().

    QTime provides a full set of operators to compare two QTime objects; an
    earlier time is considered smaller than a later one; if A.**msecsTo** (B) is
    positive, then A < B.

    QTime objects can also be created from a text representation using
    **fromString** () and converted to a string representation using
    **toString** (). All conversion to and from string formats is done using the
    C locale. For localized conversions, see **QLocale** .

    **See also** **QDate**  and **QDateTime** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtime.html#QTime-1

        **QTime::QTime()**

        Constructs a null time object. For a null time, **isNull** () returns
        `true` and **isValid** () returns `false`. If you need a zero time, use
        QTime(0, 0). For the start of a day, see **QDate::startOfDay** ().

        **See also** **isNull** () and **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, h: int, m: int, second: int = ..., msec: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtime.html#QTime-2

        **QTime::QTime(int h , int m , int s = 0, int ms = 0)**

        Constructs a time with hour **h** , minute **m** , seconds **s** and
        milliseconds **ms**.

        **h** must be in the range 0 to 23, **m** and **s** must be in the range
        0 to 59, and **ms** must be in the range 0 to 999.

        **See also** **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QTime") -> None:
        """
        https://doc.qt.io/qt-6/qtime.html#QTime-1

        **QTime::QTime()**

        Constructs a null time object. For a null time, **isNull** () returns
        `true` and **isValid** () returns `false`. If you need a zero time, use
        QTime(0, 0). For the start of a day, see **QDate::startOfDay** ().

        **See also** **isNull** () and **isValid** ().
        """
        ...

    def msecsTo(self, t: typing.Union["QTime", datetime.time]) -> int:
        """
        https://doc.qt.io/qt-6/qtime.html#msecsTo

        **int QTime::msecsTo(QTime t ) const**

        Returns the number of milliseconds from this time to **t**. If **t** is
        earlier than this time, the number of milliseconds returned is negative.

        Because **QTime**  measures time within a day and there are 86400
        seconds in a day, the result is always between -86400000 and 86400000
        ms.

        Returns 0 if either time is invalid.

        **See also** **secsTo** (), **addMSecs** (), and **QDateTime::msecsTo**
        ().
        """
        ...

    def secsTo(self, t: typing.Union["QTime", datetime.time]) -> int:
        """
        https://doc.qt.io/qt-6/qtime.html#secsTo

        **int QTime::secsTo(QTime t ) const**

        Returns the number of seconds from this time to **t**. If **t** is
        earlier than this time, the number of seconds returned is negative.

        Because **QTime**  measures time within a day and there are 86400
        seconds in a day, the result is always between -86400 and 86400.

        secsTo() does not take into account any milliseconds.

        Returns 0 if either time is invalid.

        **See also** **addSecs** () and **QDateTime::secsTo** ().
        """
        ...

    def msecsSinceStartOfDay(self) -> int:
        """
        https://doc.qt.io/qt-6/qtime.html#msecsSinceStartOfDay

        **int QTime::msecsSinceStartOfDay() const**

        Returns the number of msecs since the start of the day, i.e. since
        00:00:00.

        **See also** **fromMSecsSinceStartOfDay** ().
        """
        ...

    @staticmethod
    def fromMSecsSinceStartOfDay(msecs: int) -> "QTime":
        """
        https://doc.qt.io/qt-6/qtime.html#fromMSecsSinceStartOfDay

        **[static] QTime QTime::fromMSecsSinceStartOfDay(int msecs )**

        Returns a new **QTime**  instance with the time set to the number of
        **msecs** since the start of the day, i.e. since 00:00:00.

        If **msecs** falls outside the valid range an invalid **QTime**  will be
        returned.

        **See also** **msecsSinceStartOfDay** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromString(string: str, format: Qt.DateFormat = ...) -> "QTime":
        """
        https://doc.qt.io/qt-6/qtime.html#fromString

        **[static] QTime QTime::fromString(const QString & string ,
        Qt::DateFormat format = Qt::TextDate)**

        Returns the time represented in the **string** as a **QTime**  using the
        **format** given, or an invalid time if this is not possible.

        **See also** **toString** () and **QLocale::toTime** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromString(s: str, format: str) -> "QTime":
        """
        https://doc.qt.io/qt-6/qtime.html#fromString-1

        **[static, since 6.0] QTime QTime::fromString(QStringView string ,
        Qt::DateFormat format = Qt::TextDate)**

        This is an overloaded function.

        This function was introduced in Qt 6.0.
        """
        ...

    @staticmethod
    def currentTime() -> "QTime":
        """
        https://doc.qt.io/qt-6/qtime.html#currentTime

        **[static] QTime QTime::currentTime()**

        Returns the current time as reported by the system clock.

        Note that the accuracy depends on the accuracy of the underlying
        operating system; not all systems provide 1-millisecond accuracy.

        Furthermore, currentTime() only increases within each day; it shall drop
        by 24 hours each time midnight passes; and, beside this, changes in it
        may not correspond to elapsed time, if a daylight-saving transition
        intervenes.

        **See also** **QDateTime::currentDateTime** () and
        **QDateTime::currentDateTimeUtc** ().
        """
        ...

    def addMSecs(self, ms: int) -> "QTime":
        """
        https://doc.qt.io/qt-6/qtime.html#addMSecs

        **QTime QTime::addMSecs(int ms ) const**

        Returns a **QTime**  object containing a time **ms** milliseconds later
        than the time of this object (or earlier if **ms** is negative).

        Note that the time will wrap if it passes midnight. See **addSecs** ()
        for an example.

        Returns a null time if this time is invalid.

        **See also** **addSecs** (), **msecsTo** (), and **QDateTime::addMSecs**
        ().
        """
        ...

    def addSecs(self, secs: int) -> "QTime":
        """
        https://doc.qt.io/qt-6/qtime.html#addSecs

        **QTime QTime::addSecs(int s ) const**

        Returns a **QTime**  object containing a time **s** seconds later than
        the time of this object (or earlier if **s** is negative).

        Note that the time will wrap if it passes midnight.

        Returns a null time if this time is invalid.

        Example:

        QTime n(14, 0, 0);                // n == 14:00:00
            QTime t;
            t =
        n.addSecs(70);                // t == 14:01:10
            t = n.addSecs(-70);
        // t == 13:58:50
            t = n.addSecs(10 * 60 * 60 + 5);  // t == 00:00:05
        t = n.addSecs(-15 * 60 * 60);     // t == 23:00:00

        **See also** **addMSecs** (), **secsTo** (), and **QDateTime::addSecs**
        ().
        """
        ...

    def setHMS(self, h: int, m: int, s: int, msec: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qtime.html#setHMS

        **bool QTime::setHMS(int h , int m , int s , int ms = 0)**

        Sets the time to hour **h** , minute **m** , seconds **s** and
        milliseconds **ms**.

        **h** must be in the range 0 to 23, **m** and **s** must be in the range
        0 to 59, and **ms** must be in the range 0 to 999. Returns `true` if the
        set time is valid; otherwise returns `false`.

        **See also** **isValid** ().
        """
        ...

    @typing.overload
    def toString(self, format: Qt.DateFormat = ...) -> str:
        """
        https://doc.qt.io/qt-6/qtime.html#toString-1

        **QString QTime::toString(Qt::DateFormat format = Qt::TextDate) const**

        This is an overloaded function.

        Returns the time as a string. The **format** parameter determines the
        format of the string.

        If **format** is **Qt::TextDate** , the string format is HH:mm:ss; e.g.
        1 second before midnight would be "23:59:59".

        If **format** is **Qt::ISODate** , the string format corresponds to the
        ISO 8601 extended specification for representations of dates,
        represented by HH:mm:ss. To include milliseconds in the ISO 8601 date,
        use the **format** **Qt::ISODateWithMs** , which corresponds to
        HH:mm:ss.zzz.

        If the **format** is **Qt::RFC2822Date** , the string is formatted in an
        **RFC 2822**  compatible way. An example of this formatting is
        "23:59:20".

        If the time is invalid, an empty string will be returned.

        **See also** **fromString** (), **QDate::toString** (),
        **QDateTime::toString** (), and **QLocale::toString** ().
        """
        ...

    @typing.overload
    def toString(self, format: str) -> str:
        """
        https://doc.qt.io/qt-6/qtime.html#toString-1

        **QString QTime::toString(Qt::DateFormat format = Qt::TextDate) const**

        This is an overloaded function.

        Returns the time as a string. The **format** parameter determines the
        format of the string.

        If **format** is **Qt::TextDate** , the string format is HH:mm:ss; e.g.
        1 second before midnight would be "23:59:59".

        If **format** is **Qt::ISODate** , the string format corresponds to the
        ISO 8601 extended specification for representations of dates,
        represented by HH:mm:ss. To include milliseconds in the ISO 8601 date,
        use the **format** **Qt::ISODateWithMs** , which corresponds to
        HH:mm:ss.zzz.

        If the **format** is **Qt::RFC2822Date** , the string is formatted in an
        **RFC 2822**  compatible way. An example of this formatting is
        "23:59:20".

        If the time is invalid, an empty string will be returned.

        **See also** **fromString** (), **QDate::toString** (),
        **QDateTime::toString** (), and **QLocale::toString** ().
        """
        ...

    def msec(self) -> int:
        """
        https://doc.qt.io/qt-6/qtime.html#msec

        **int QTime::msec() const**

        Returns the millisecond part (0 to 999) of the time.

        Returns -1 if the time is invalid.

        **See also** **hour** (), **minute** (), and **second** ().
        """
        ...

    def second(self) -> int:
        """
        https://doc.qt.io/qt-6/qtime.html#second

        **int QTime::second() const**

        Returns the second part (0 to 59) of the time.

        Returns -1 if the time is invalid.

        **See also** **hour** (), **minute** (), and **msec** ().
        """
        ...

    def minute(self) -> int:
        """
        https://doc.qt.io/qt-6/qtime.html#minute

        **int QTime::minute() const**

        Returns the minute part (0 to 59) of the time.

        Returns -1 if the time is invalid.

        **See also** **hour** (), **second** (), and **msec** ().
        """
        ...

    def hour(self) -> int:
        """
        https://doc.qt.io/qt-6/qtime.html#hour

        **int QTime::hour() const**

        Returns the hour part (0 to 23) of the time.

        Returns -1 if the time is invalid.

        **See also** **minute** (), **second** (), and **msec** ().
        """
        ...

    @typing.overload
    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtime.html#isValid

        **bool QTime::isValid() const**

        Returns `true` if the time is valid; otherwise returns `false`. For
        example, the time 23:30:55.746 is valid, but 24:12:30 is invalid.

        **See also** **isNull** ().
        """
        ...

    @typing.overload
    @staticmethod
    def isValid(h: int, m: int, s: int, msec: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qtime.html#isValid-1

        **[static] bool QTime::isValid(int h , int m , int s , int ms = 0)**

        This is an overloaded function.

        Returns `true` if the specified time is valid; otherwise returns false.

        The time is valid if **h** is in the range 0 to 23, **m** and **s** are
        in the range 0 to 59, and **ms** is in the range 0 to 999.

        Example:

        QTime::isValid(21, 10, 30); // returns true
            QTime::isValid(22, 5,
        62); // returns false
        """
        ...

    def __bool__(self) -> int:
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtime.html#isNull

        **bool QTime::isNull() const**

        Returns `true` if the time is null (i.e., the **QTime**  object was
        constructed using the default constructor); otherwise returns false. A
        null time is also an invalid time.

        **See also** **isValid** ().
        """
        ...

    def toPyTime(self) -> datetime.time:
        ...

    def __hash__(self) -> int:
        ...

    def __repr__(self) -> str:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from typing import TypeVar, Union
from PyQt6.sip import *

SIP_VERSION: int = ...
SIP_VERSION_STR: str = ...
T = TypeVar("T")
Buffer = Union[bytes, bytearray, memoryview, array, voidptr]


def assign(obj: simplewrapper, other: simplewrapper) -> None:
    ...


def cast(obj: simplewrapper, type: wrappertype) -> simplewrapper:
    ...


def delete(obj: simplewrapper) -> None:
    ...


def dump(obj: simplewrapper) -> None:
    ...


def enableautoconversion(type: wrappertype, enable: bool) -> bool:
    ...


def isdeleted(obj: simplewrapper) -> bool:
    ...


def ispycreated(obj: simplewrapper) -> bool:
    ...


def ispyowned(obj: simplewrapper) -> bool:
    ...


def setdeleted(obj: simplewrapper) -> None:
    ...


def settracemask(mask: int) -> None:
    ...


def transferback(obj: wrapper) -> None:
    ...


def transferto(obj: wrapper, owner: wrapper) -> None:
    ...


def unwrapinstance(obj: simplewrapper) -> None:
    ...


def wrapinstance(addr: int, type: wrappertype) -> simplewrapper:
    ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtDBus import *


class QDBusPendingCallWatcher(QtCore.QObject, QDBusPendingCall):
    """
    https://doc.qt.io/qt-6/qdbuspendingcallwatcher.html

    **Detailed Description**

    The QDBusPendingCallWatcher provides the **finished** () signal that will be
    emitted when a reply arrives.

    It is usually used like the following example:

    **QDBusPendingCall**  async = iface->asyncCall("RemoteMethod", value1,
    value2);
            **QDBusPendingCallWatcher**  *watcher = new
    **QDBusPendingCallWatcher** (async, this);

            **QObject**
    ::connect(watcher, SIGNAL(finished(**QDBusPendingCallWatcher** *)),
    this, SLOT(callFinishedSlot(**QDBusPendingCallWatcher** *)));

    Note that it is not necessary to keep the original **QDBusPendingCall**
    object around since QDBusPendingCallWatcher inherits from that class too.

    The slot connected to by the above code could be something similar to the
    following:

    void
    DBus_PendingCall_Interface::callFinishedSlot(**QDBusPendingCallWatcher**
    *call)
        {
            **QDBusPendingReply** <**QString** , **QByteArray** >
    reply = *call;
            if (reply.isError()) {
                showError();
    } else {
                **QString**  text = reply.argumentAt<0>();
    **QByteArray**  data = reply.argumentAt<1>();
                showReply(text,
    data);
            }
            call->deleteLater();
        }

    Note the use of **QDBusPendingReply**  to validate the argument types in the
    reply. If the reply did not contain exactly two arguments (one string and
    one **QByteArray** ), **QDBusPendingReply::isError** () will return true.

    **See also** **QDBusPendingReply** .
    """

    def __init__(
        self, call: QDBusPendingCall, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdbuspendingcallwatcher.html#QDBusPendingCallWatc
        her

        **QDBusPendingCallWatcher::QDBusPendingCallWatcher(const
        QDBusPendingCall & call , QObject * parent = nullptr)**

        Creates a QDBusPendingCallWatcher object to watch for replies on the
        asynchronous pending call **call** and sets this object's parent to
        **parent**.
        """
        ...

    def waitForFinished(self) -> None:
        """
        https://doc.qt.io/qt-6/qdbuspendingcallwatcher.html#waitForFinished

        **void QDBusPendingCallWatcher::waitForFinished()**

        Suspends the execution of the calling thread until the reply is received
        and processed. After this function returns, **isFinished** () should
        return true, indicating the reply's contents are ready to be processed.

        **See also** **QDBusPendingReply::waitForFinished** ().
        """
        ...

    def isFinished(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdbuspendingcallwatcher.html#isFinished

        **bool QDBusPendingCallWatcher::isFinished() const**

        Returns `true` if the pending call has finished processing and the reply
        has been received.

        Note that this function only changes state if you call
        **waitForFinished** () or if an external D-Bus event happens, which in
        general only happens if you return to the event loop execution.

        **See also** **QDBusPendingReply::isFinished** ().
        """
        ...

    @property
    def finished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdbuspendingcallwatcher.html#finished

        **[signal] void
        QDBusPendingCallWatcher::finished(QDBusPendingCallWatcher * self =
        nullptr)**

        This signal is emitted when the pending call has finished and its reply
        is available. The **self** parameter is a pointer to the object itself,
        passed for convenience so that the slot can access the properties and
        determine the contents of the reply.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtCore import *


class QDynamicPropertyChangeEvent(QEvent):
    """
    https://doc.qt.io/qt-6/qdynamicpropertychangeevent.html

    **Detailed Description**

    Dynamic property change events are sent to objects when properties are
    dynamically added, changed or removed using **QObject::setProperty** ().
    """

    def __init__(self, name: QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qdynamicpropertychangeevent.html#QDynamicProperty
        ChangeEvent-2

        **QDynamicPropertyChangeEvent::QDynamicPropertyChangeEvent(const
        QByteArray & name )**

        Constructs a dynamic property change event object with the property name
        set to **name**.
        """
        ...

    def clone(self) -> "QDynamicPropertyChangeEvent":
        ...

    def propertyName(self) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qdynamicpropertychangeevent.html#propertyName

        **QByteArray QDynamicPropertyChangeEvent::propertyName() const**

        Returns the name of the dynamic property that was added, changed or
        removed.

        **See also** **QObject::setProperty** () and
        **QObject::dynamicPropertyNames** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtBluetooth import *
import enum


class QLowEnergyAdvertisingParameters(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qlowenergyadvertisingparameters.html

    **Detailed Description**

    When running the advertising procedure, a number of parameters can be
    configured, such as how fast to advertise or which clients, if any, can
    connect to the advertising device. These parameters are set via this class,
    and their values will be used when advertising is started by calling
    **QLowEnergyController::startAdvertising** ().

    **See also** **QLowEnergyAdvertisingData**  and
    **QLowEnergyController::startAdvertising** ().
    """

    class FilterPolicy(enum.Enum):
        IgnoreWhiteList: QLowEnergyAdvertisingParameters = ...
        UseWhiteListForScanning: QLowEnergyAdvertisingParameters = ...
        UseWhiteListForConnecting: QLowEnergyAdvertisingParameters = ...
        UseWhiteListForScanningAndConnecting: QLowEnergyAdvertisingParameters = ...

    class Mode(enum.Enum):
        AdvInd: QLowEnergyAdvertisingParameters = ...
        AdvScanInd: QLowEnergyAdvertisingParameters = ...
        AdvNonConnInd: QLowEnergyAdvertisingParameters = ...

    class AddressInfo(PyQt6.sip.simplewrapper):
        address: QBluetoothAddress = ...
        type = ...

        @typing.overload
        def __init__(
            self, addr: QBluetoothAddress, t: "QLowEnergyController.RemoteAddressType"
        ) -> None:
            ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QLowEnergyAdvertisingParameters.AddressInfo") -> None:
            ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingparameters.html#QLowEnergyAd
        vertisingParameters

        **QLowEnergyAdvertisingParameters::QLowEnergyAdvertisingParameters()**

        Constructs a new object of this class. All values are initialized to
        their defaults according to the Bluetooth Low Energy specification.
        """
        ...

    @typing.overload
    def __init__(self, other: "QLowEnergyAdvertisingParameters") -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingparameters.html#QLowEnergyAd
        vertisingParameters-1

        **QLowEnergyAdvertisingParameters::QLowEnergyAdvertisingParameters(const
        QLowEnergyAdvertisingParameters & other )**

        Constructs a new object of this class that is a copy of **other**.
        """
        ...

    def swap(self, other: "QLowEnergyAdvertisingParameters") -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingparameters.html#swap

        **void
        QLowEnergyAdvertisingParameters::swap(QLowEnergyAdvertisingParameters &
        other )**

        Swaps this object with **other**.
        """
        ...

    def maximumInterval(self) -> int:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingparameters.html#maximumInter
        val

        **int QLowEnergyAdvertisingParameters::maximumInterval() const**

        Returns the maximum advertising interval in milliseconds. The default is
        1280.
        """
        ...

    def minimumInterval(self) -> int:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingparameters.html#minimumInter
        val

        **int QLowEnergyAdvertisingParameters::minimumInterval() const**

        Returns the minimum advertising interval in milliseconds. The default is
        1280.
        """
        ...

    def setInterval(self, minimum: int, maximum: int) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingparameters.html#setInterval

        **void QLowEnergyAdvertisingParameters::setInterval(quint16 minimum ,
        quint16 maximum )**

        Sets the advertising interval. This is a range that gives the controller
        an upper and a lower bound for how often to send the advertising data.
        Both **minimum** and **maximum** are given in milliseconds. If
        **maximum** is smaller than **minimum** , it will be set to the value of
        **minimum**.

        **Note:** There are limits for the minimum and maximum interval; the
        exact values depend on the mode. If they are exceeded, the lowest or
        highest possible value will be used, respectively.
        """
        ...

    def filterPolicy(self) -> "QLowEnergyAdvertisingParameters.FilterPolicy":
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingparameters.html#filterPolicy

        **QLowEnergyAdvertisingParameters::FilterPolicy
        QLowEnergyAdvertisingParameters::filterPolicy() const**

        Returns the filter policy that determines how the white list is used.
        The default is **QLowEnergyAdvertisingParameters::IgnoreWhiteList** .
        """
        ...

    def whiteList(self) -> typing.List["QLowEnergyAdvertisingParameters.AddressInfo"]:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingparameters.html#whiteList

        **QList<QLowEnergyAdvertisingParameters::AddressInfo>
        QLowEnergyAdvertisingParameters::whiteList() const**

        Returns the white list used for filtering scan and connection requests.
        By default, this list is empty.

        **See also** **setWhiteList** ().
        """
        ...

    def setWhiteList(
        self,
        whiteList: typing.Iterable["QLowEnergyAdvertisingParameters.AddressInfo"],
        policy: "QLowEnergyAdvertisingParameters.FilterPolicy",
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingparameters.html#setWhiteList

        **void QLowEnergyAdvertisingParameters::setWhiteList(const
        QList<QLowEnergyAdvertisingParameters::AddressInfo> & whiteList ,
        QLowEnergyAdvertisingParameters::FilterPolicy policy )**

        Sets the white list that is potentially used for filtering scan and
        connection requests. The **whiteList** parameter is the list of
        addresses to use for filtering, and **policy** specifies how exactly to
        use **whiteList**.

        **See also** **whiteList** ().
        """
        ...

    def mode(self) -> "QLowEnergyAdvertisingParameters.Mode":
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingparameters.html#mode

        **QLowEnergyAdvertisingParameters::Mode
        QLowEnergyAdvertisingParameters::mode() const**

        Returns the advertising mode. The default is
        **QLowEnergyAdvertisingParameters::AdvInd** .

        **See also** **setMode** ().
        """
        ...

    def setMode(self, mode: "QLowEnergyAdvertisingParameters.Mode") -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingparameters.html#setMode

        **void QLowEnergyAdvertisingParameters::setMode(QLowEnergyAdvertisingPar
        ameters::Mode mode )**

        Sets the advertising mode to **mode**.

        **See also** **mode** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore


class QOpenGLPaintDevice(QtGui.QPaintDevice):
    """
    https://doc.qt.io/qt-6/qopenglpaintdevice.html

    **Detailed Description**

    The QOpenGLPaintDevice uses the **current** QOpenGL context to render
    **QPainter**  draw commands. The context is captured upon construction. It
    requires support for OpenGL (ES) 2.0 or higher.

    **Performance**

    The QOpenGLPaintDevice is almost always hardware accelerated and has the
    potential of being much faster than software rasterization. However, it is
    more sensitive to state changes, and therefore requires the drawing commands
    to be carefully ordered to achieve optimal performance.

    **Antialiasing and Quality**

    Antialiasing in the OpenGL paint engine is done using multisampling. Most
    hardware require significantly more memory to do multisampling and the
    resulting quality is not on par with the quality of the software paint
    engine. The OpenGL paint engine's strength lies in its performance, not its
    visual rendering quality.

    **State Changes**

    When painting to a QOpenGLPaintDevice using **QPainter** , the state of the
    current OpenGL context will be altered by the paint engine to reflect its
    needs. Applications should not rely upon the OpenGL state being reset to its
    original conditions, particularly the current shader program, OpenGL
    viewport, texture units, and drawing modes.

    **Mixing QPainter and OpenGL**

    When intermixing **QPainter**  and OpenGL, it is important to notify
    **QPainter**  that the OpenGL state may have been cluttered so it can
    restore its internal state. This is achieved by calling
    **QPainter::beginNativePainting** () before starting the OpenGL rendering
    and calling **QPainter::endNativePainting** () after finishing.

    **See also** **OpenGL Window Example** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpaintdevice.html#QOpenGLPaintDevice

        **QOpenGLPaintDevice::QOpenGLPaintDevice()**

        Constructs a QOpenGLPaintDevice.

        The QOpenGLPaintDevice is only valid for the current context.

        **See also** **QOpenGLContext::currentContext** ().
        """
        ...

    @typing.overload
    def __init__(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpaintdevice.html#QOpenGLPaintDevice-1

        **QOpenGLPaintDevice::QOpenGLPaintDevice(const QSize & size )**

        Constructs a QOpenGLPaintDevice with the given **size**.

        The QOpenGLPaintDevice is only valid for the current context.

        **See also** **QOpenGLContext::currentContext** ().
        """
        ...

    @typing.overload
    def __init__(self, width: int, height: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpaintdevice.html#QOpenGLPaintDevice-2

        **QOpenGLPaintDevice::QOpenGLPaintDevice(int width , int height )**

        Constructs a QOpenGLPaintDevice with the given **width** and **height**.

        The QOpenGLPaintDevice is only valid for the current context.

        **See also** **QOpenGLContext::currentContext** ().
        """
        ...

    def metric(self, metric: QtGui.QPaintDevice.PaintDeviceMetric) -> int:
        """
        https://doc.qt.io/qt-6/qopenglpaintdevice.html#metric

        **[override virtual protected] int
        QOpenGLPaintDevice::metric(QPaintDevice::PaintDeviceMetric metric )
        const**

        Reimplements: **QPaintDevice::metric(QPaintDevice::PaintDeviceMetric
        metric) const** .
        """
        ...

    def setDevicePixelRatio(self, devicePixelRatio: float) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpaintdevice.html#setDevicePixelRatio

        **void QOpenGLPaintDevice::setDevicePixelRatio(qreal devicePixelRatio
        )**

        Sets the device pixel ratio for the paint device to
        **devicePixelRatio**.
        """
        ...

    def ensureActiveTarget(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpaintdevice.html#ensureActiveTarget

        **[virtual] void QOpenGLPaintDevice::ensureActiveTarget()**

        This virtual method is provided as a callback to allow re-binding a
        target frame buffer object or context when different
        **QOpenGLPaintDevice**  instances are issuing draw calls alternately.

        **beginNativePainting** () will also trigger this method.

        The default implementation does nothing.
        """
        ...

    def paintFlipped(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglpaintdevice.html#paintFlipped

        **bool QOpenGLPaintDevice::paintFlipped() const**

        Returns `true` if painting is flipped around the Y-axis.

        **See also** **setPaintFlipped** ().
        """
        ...

    def setPaintFlipped(self, flipped: bool) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpaintdevice.html#setPaintFlipped

        **void QOpenGLPaintDevice::setPaintFlipped(bool flipped )**

        Sets whether painting should be flipped around the Y-axis or not to
        **flipped**.

        **See also** **paintFlipped** ().
        """
        ...

    def setDotsPerMeterY(self, a0: float) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpaintdevice.html#setDotsPerMeterY

        **void QOpenGLPaintDevice::setDotsPerMeterY(qreal dpmy )**

        Sets the number of pixels per meter vertically to **dpmy**.

        **See also** **dotsPerMeterY** ().
        """
        ...

    def setDotsPerMeterX(self, a0: float) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpaintdevice.html#setDotsPerMeterX

        **void QOpenGLPaintDevice::setDotsPerMeterX(qreal dpmx )**

        Sets the number of pixels per meter horizontally to **dpmx**.

        **See also** **dotsPerMeterX** ().
        """
        ...

    def dotsPerMeterY(self) -> float:
        """
        https://doc.qt.io/qt-6/qopenglpaintdevice.html#dotsPerMeterY

        **qreal QOpenGLPaintDevice::dotsPerMeterY() const**

        Returns the number of pixels per meter vertically.

        **See also** **setDotsPerMeterY** ().
        """
        ...

    def dotsPerMeterX(self) -> float:
        """
        https://doc.qt.io/qt-6/qopenglpaintdevice.html#dotsPerMeterX

        **qreal QOpenGLPaintDevice::dotsPerMeterX() const**

        Returns the number of pixels per meter horizontally.

        **See also** **setDotsPerMeterX** ().
        """
        ...

    def setSize(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpaintdevice.html#setSize

        **void QOpenGLPaintDevice::setSize(const QSize & size )**

        Sets the pixel size of the paint device to **size**.

        **See also** **size** ().
        """
        ...

    def size(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qopenglpaintdevice.html#size

        **QSize QOpenGLPaintDevice::size() const**

        Returns the pixel size of the paint device.

        **See also** **setSize** ().
        """
        ...

    def context(self) -> QtGui.QOpenGLContext:
        """
        https://doc.qt.io/qt-6/qopenglpaintdevice.html#context

        **QOpenGLContext *QOpenGLPaintDevice::context() const**

        Returns the OpenGL context associated with the paint device.
        """
        ...

    def paintEngine(self) -> QtGui.QPaintEngine:
        """
        https://doc.qt.io/qt-6/qopenglpaintdevice.html#paintEngine

        **[override virtual] QPaintEngine *QOpenGLPaintDevice::paintEngine()
        const**

        Reimplements: **QPaintDevice::paintEngine() const** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QCborStreamWriter(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcborstreamwriter.html

    **Detailed Description**

    This class can be used to quickly encode a stream of CBOR content directly
    to either a **QByteArray**  or **QIODevice** . CBOR is the Concise Binary
    Object Representation, a very compact form of binary data encoding that is
    compatible with JSON. It was created by the IETF Constrained RESTful
    Environments (CoRE) WG, which has used it in many new RFCs. It is meant to
    be used alongside the **CoAP protocol** .

    QCborStreamWriter provides a StAX-like API, similar to that of
    **QXmlStreamWriter** . It is rather low-level and requires a bit of
    knowledge of CBOR encoding. For a simpler API, see **QCborValue**  and
    especially the encoding function **QCborValue::toCbor** ().

    The typical use of QCborStreamWriter is to create the object on the target
    **QByteArray**  or **QIODevice** , then call one of the **append** ()
    overloads with the desired type to be encoded. To create arrays and maps,
    QCborStreamWriter provides **startArray** () and **startMap** () overloads,
    which must be terminated by the corresponding **endArray** () and **endMap**
    () functions.

    The following example encodes the equivalent of this JSON content:

    { "label": "journald", "autoDetect": false, "condition": "libs.journald",
    "output": [ "privateFeature" ] }

    writer.startMap(4);    // 4 elements in the map
    writer.append(QLatin1String("label"));
    writer.append(QLatin1String("journald"));
    writer.append(QLatin1String("autoDetect"));
           writer.append(false);
    writer.append(QLatin1String("condition"));
    writer.append(QLatin1String("libs.journald"));
    writer.append(QLatin1String("output"));
           writer.startArray(1);
    writer.append(QLatin1String("privateFeature"));
           writer.endArray();
    writer.endMap();

    **CBOR support**

    QCborStreamWriter supports all CBOR features required to create canonical
    and strict streams. It implements almost all of the features specified in
    **RFC 7049** .

    The following table lists the CBOR features that QCborStreamWriter supports.

    FeatureSupport
    Unsigned numbersYes (full range)
    Negative numbersYes
    (full range)
    Byte stringsYes
    Text stringsYes
    Chunked stringsNo
    TagsYes (arbitrary)
    BooleansYes
    NullYes
    UndefinedYes
    Arbitrary
    simple valuesYes
    Half-precision float (16-bit)Yes
    Single-precision float
    (32-bit)Yes
    Double-precision float (64-bit)Yes
    Infinities and NaN
    floating pointYes
    Determinate-length arrays and mapsYes
    Indeterminate-
    length arrays and mapsYes
    Map key types other than strings and integersYes
    (arbitrary)

    **Canonical CBOR encoding**

    Canonical CBOR encoding is defined by **Section 3.9 of RFC 7049** .
    Canonical encoding is not a requirement for Qt's CBOR decoding
    functionality, but it may be required for some protocols. In particular,
    protocols that require the ability to reproduce the same stream identically
    may require this.

    In order to be considered "canonical", a CBOR stream must meet the following
    requirements:

    * Integers must be as small as possible. QCborStreamWriter always does this
    (no user action is required and it is not possible to write overlong
    integers).
      * Array, map and string lengths must be as short as possible.
    As above, QCborStreamWriter automatically does this.
      * Arrays, maps and
    strings must use explicit length. QCborStreamWriter always does this for
    strings; for arrays and maps, be sure to call **startArray** () and
    **startMap** () overloads with explicit length.
      * Keys in every map must
    be sorted in ascending order. QCborStreamWriter offers no help in this item:
    the developer must ensure that before calling **append** () for the map
    pairs.
      * Floating point values should be as small as possible.
    QCborStreamWriter will not convert floating point values; it is up to the
    developer to perform this check prior to calling **append** () (see those
    functions' examples).

    **Strict CBOR mode**

    Strict mode is defined by **Section 3.10 of RFC 7049** . As for Canonical
    encoding above, QCborStreamWriter makes it possible to create strict CBOR
    streams, but does not require them or validate that the output is so.

    * Keys in a map must be unique. QCborStreamWriter performs no validation of
    map keys.
      * Tags may be required to be paired only with the correct types,
    according to their specification. QCborStreamWriter performs no validation
    of tag usage.
      * Text Strings must be properly-encoded UTF-8.
    QCborStreamWriter always writes proper UTF-8 for strings added with
    **append** (), but performs no validation for strings added with
    **appendTextString** ().

    **Invalid CBOR stream**

    It is also possible to misuse QCborStreamWriter and produce invalid CBOR
    streams that will fail to be decoded by a receiver. The following actions
    will produce invalid streams:

    * Append a tag and not append the corresponding tagged value
    (QCborStreamWriter produces no diagnostic).
      * Append too many or too few
    items to an array or map with explicit length (**endMap** () and
    **endArray** () will return false and QCborStreamWriter will log with
    **qWarning** ()).

    **See also** **QCborStreamReader** , **QCborValue** , and
    **QXmlStreamWriter** .
    """

    @typing.overload
    def __init__(self, device: QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#QCborStreamWriter

        **QCborStreamWriter::QCborStreamWriter(QIODevice * device )**

        Creates a QCborStreamWriter object that will write the stream to
        **device**. The device must be opened before the first **append** ()
        call is made. This constructor can be used with any class that derives
        from **QIODevice** , such as **QFile** , **QProcess**  or **QTcpSocket**
        .

        QCborStreamWriter has no buffering, so every **append** () call will
        result in one or more calls to the device's **write** () method.

        The following example writes an empty map to a file:

        **QFile**  f("output", **QIODevice** ::WriteOnly);
        QCborStreamWriter writer(&f);
               writer.startMap(0);
        writer.endMap();

        QCborStreamWriter does not take ownership of **device**.

        **See also** **device** () and **setDevice** ().
        """
        ...

    @typing.overload
    def __init__(self, data: QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#QCborStreamWriter-1

        **QCborStreamWriter::QCborStreamWriter(QByteArray * data )**

        Creates a QCborStreamWriter object that will append the stream to
        **data**. All streaming is done immediately to the byte array, without
        the need for flushing any buffers.

        The following example writes a number to a byte array then returns it.

        **QByteArray**  encodedNumber(**qint64**  value)
               {
        **QByteArray**  ba;
                   **QCborStreamWriter**  writer(&ba);
        writer.append(value);
                   return ba;
               }

        QCborStreamWriter does not take ownership of **data**.
        """
        ...

    def endMap(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#endMap

        **bool QCborStreamWriter::endMap()**

        Terminates the map started by either overload of **startMap** () and
        returns true if the correct number of elements was added to the array.
        This function must be called for every **startMap** () used.

        A return of false indicates error in the application and an
        unrecoverable error in this stream. **QCborStreamWriter**  also writes a
        warning using **qWarning** () if that happens.

        Calling this function when the current container is not a map is also an
        error, though **QCborStreamWriter**  cannot currently detect this
        condition.

        **See also** **startMap** (), **startMap** (quint64), and **endArray**
        ().
        """
        ...

    @typing.overload
    def startMap(self) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#startMap

        **void QCborStreamWriter::startMap()**

        Starts a CBOR Map with indeterminate length in the CBOR stream. Each
        startMap() call must be paired with one **endMap** () call and the
        current CBOR element extends until the end of the map.

        The map created by this function has no explicit length. Instead, its
        length is implied by the elements contained in it. Note, however, that
        use of indeterminate-length maps is not compliant with canonical CBOR
        encoding (canonical encoding also requires keys to be unique and in
        sorted order).

        The following example appends elements from the list of int and string
        pairs passed as input:

        void appendMap(**QCborStreamWriter**  &writer, const **QList**
        <QPair<int, **QString** >> &values)
               {
        writer.startMap();
                   for (const auto pair : values) {
        writer.append(pair.first)
                       writer.append(pair.second);
        }
                   writer.endMap();
               }

        **See also** **startMap** (quint64), **endMap** (), **startArray** (),
        **QCborStreamReader::isMap** (), and
        **QCborStreamReader::isLengthKnown** ().
        """
        ...

    @typing.overload
    def startMap(self, count: int) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#startMap-1

        **void QCborStreamWriter::startMap(quint64 count )**

        This is an overloaded function.

        Starts a CBOR Map with explicit length of **count** items in the CBOR
        stream. Each startMap call must be paired with one **endMap** () call
        and the current CBOR element extends until the end of the map.

        The map created by this function has an explicit length and therefore
        exactly **count** pairs of items must be added to the CBOR stream.
        Adding fewer or more items will result in failure during **endMap** ()
        and the CBOR stream will be corrupt. However, explicit-length map are
        required by canonical CBOR encoding.

        The following example appends all strings found in the **QMap**  passed
        as input:

        void appendMap(**QCborStreamWriter**  &writer, const **QMap** <int,
        **QString** > &map)
               {
                   writer.startMap(map.size());
        for (auto it = map.begin(); it != map.end(); ++it) {
        writer.append(it.key());
                       writer.append(it.value());
        }
                   writer.endMap();
               }

        **Size limitations** : The parameter to this function is quint64, which
        would seem to allow up to 264-1 pairs in the map. However, both
        **QCborStreamWriter**  and **QCborStreamReader**  are currently limited
        to 231-1 items on 32-bit systems and 263-1 items on 64-bit ones. Also
        note that **QCborMap**  is currently limited to 226 elements in any
        platform.

        **See also** **startMap** (), **endMap** (), **startArray** (),
        **QCborStreamReader::isMap** (), and
        **QCborStreamReader::isLengthKnown** ().
        """
        ...

    def endArray(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#endArray

        **bool QCborStreamWriter::endArray()**

        Terminates the array started by either overload of **startArray** () and
        returns true if the correct number of elements was added to the array.
        This function must be called for every **startArray** () used.

        A return of false indicates error in the application and an
        unrecoverable error in this stream. **QCborStreamWriter**  also writes a
        warning using **qWarning** () if that happens.

        Calling this function when the current container is not an array is also
        an error, though **QCborStreamWriter**  cannot currently detect this
        condition.

        **See also** **startArray** (), **startArray** (quint64), and **endMap**
        ().
        """
        ...

    @typing.overload
    def startArray(self) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#startArray

        **void QCborStreamWriter::startArray()**

        Starts a CBOR Array with indeterminate length in the CBOR stream. Each
        startArray() call must be paired with one **endArray** () call and the
        current CBOR element extends until the end of the array.

        The array created by this function has no explicit length. Instead, its
        length is implied by the elements contained in it. Note, however, that
        use of indeterminate-length arrays is not compliant with canonical CBOR
        encoding.

        The following example appends elements from the list of strings passed
        as input:

        void appendList(**QCborStreamWriter**  &writer, const **QList**
        <**QString** > &values)
               {
                   writer.startArray();
        for (const **QString**  &s : values)
                       writer.append(s);
        writer.endArray();
               }

        **See also** **startArray** (quint64), **endArray** (), **startMap** (),
        **QCborStreamReader::isArray** (), and
        **QCborStreamReader::isLengthKnown** ().
        """
        ...

    @typing.overload
    def startArray(self, count: int) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#startArray-1

        **void QCborStreamWriter::startArray(quint64 count )**

        This is an overloaded function.

        Starts a CBOR Array with explicit length of **count** items in the CBOR
        stream. Each startArray call must be paired with one **endArray** ()
        call and the current CBOR element extends until the end of the array.

        The array created by this function has an explicit length and therefore
        exactly **count** items must be added to the CBOR stream. Adding fewer
        or more items will result in failure during **endArray** () and the CBOR
        stream will be corrupt. However, explicit-length arrays are required by
        canonical CBOR encoding.

        The following example appends all strings found in the **QStringList**
        passed as input:

        void appendList(**QCborStreamWriter**  &writer, const **QStringList**
        &list)
               {
                   writer.startArray(list.size());
        for (const **QString**  &s : list)
                       writer.append(s);
        writer.endArray();
               }

        **Size limitations** : The parameter to this function is quint64, which
        would seem to allow up to 264-1 elements in the array. However, both
        **QCborStreamWriter**  and **QCborStreamReader**  are currently limited
        to 232-2 items on 32-bit systems and 264-2 items on 64-bit ones. Also
        note that **QCborArray**  is currently limited to 227 elements in any
        platform.

        **See also** **startArray** (), **endArray** (), **startMap** (),
        **QCborStreamReader::isArray** (), and
        **QCborStreamReader::isLengthKnown** ().
        """
        ...

    def appendUndefined(self) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#appendUndefined

        **void QCborStreamWriter::appendUndefined()**

        Appends a CBOR Undefined value to the stream. This function is
        equivalent to (and implemented as):

        writer.append(**QCborSimpleType** ::Undefined);

        **See also** **append** (QCborSimpleType) and
        **QCborStreamReader::isUndefined** ().
        """
        ...

    def appendNull(self) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#appendNull

        **void QCborStreamWriter::appendNull()**

        Appends a CBOR Null value to the stream. This function is equivalent to
        (and implemented as):

        writer.append(**QCborSimpleType** ::Null);

        **See also** **append** (std::nullptr_t), **append** (QCborSimpleType),
        and **QCborStreamReader::isNull** ().
        """
        ...

    @typing.overload
    def append(self, ba: QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#append

        **void QCborStreamWriter::append(quint64 u )**

        This is an overloaded function.

        Appends the 64-bit unsigned value **u** to the CBOR stream, creating a
        CBOR Unsigned Integer value. In the following example, we write the
        values 0, 232 and `UINT64_MAX`:

        writer.append(0U);
               writer.append(Q_UINT64_C(4294967296));
        writer.append(std::numeric_limits<**quint64** >::max());

        **See also** **QCborStreamReader::isUnsignedInteger** () and
        **QCborStreamReader::toUnsignedInteger** ().
        """
        ...

    @typing.overload
    def append(self, str: str) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#append-1

        **void QCborStreamWriter::append(qint64 i )**

        This is an overloaded function.

        Appends the 64-bit signed value **i** to the CBOR stream. This will
        create either a CBOR Unsigned Integer or CBOR NegativeInteger value
        based on the sign of the parameter. In the following example, we write
        the values 0, -1, 232 and `INT64_MAX`:

        writer.append(0);
               writer.append(-1);
        writer.append(Q_INT64_C(4294967296));
        writer.append(std::numeric_limits<**qint64** >::max());

        **See also** **QCborStreamReader::isInteger** () and
        **QCborStreamReader::toInteger** ().
        """
        ...

    @typing.overload
    def append(self, tag: QCborKnownTags) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#append-2

        **void QCborStreamWriter::append(QCborNegativeInteger n )**

        This is an overloaded function.

        Appends the 64-bit negative value **n** to the CBOR stream.
        QCborNegativeInteger is a 64-bit enum that holds the absolute value of
        the negative number we want to write. If n is zero, the value written
        will be equivalent to 264 (that is, -18,446,744,073,709,551,616).

        In the following example, we write the values -1, -232 and INT64_MIN:

        writer.append(QCborNegativeInteger(1));
        writer.append(QCborNegativeInteger(Q_INT64_C(4294967296)));
        writer.append(QCborNegativeInteger(-**quint64**
        (std::numeric_limits<**qint64** >::min())));

        Note how this function can be used to encode numbers that cannot fit a
        standard computer's 64-bit signed integer like **qint64** . That is, if
        **n** is larger than `std::numeric_limits<qint64>::max()` or is 0, this
        will represent a negative number smaller than
        `std::numeric_limits<qint64>::min()`.

        **See also** **QCborStreamReader::isNegativeInteger** () and
        **QCborStreamReader::toNegativeInteger** ().
        """
        ...

    @typing.overload
    def append(self, st: QCborSimpleType) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#append-3

        **void QCborStreamWriter::append(const QByteArray & ba )**

        This is an overloaded function.

        Appends the byte array **ba** to the stream, creating a CBOR Byte String
        value. **QCborStreamWriter**  will attempt to write the entire string in
        one chunk.

        The following example will load and append the contents of a file to the
        stream:

        void writeFile(**QCborStreamWriter**  &writer, const **QString**
        &fileName)
               {
                   **QFile**  f(fileName);
                   if
        (f.open(**QIODevice** ::ReadOnly))
        writer.append(f.readAll());
               }

        As the example shows, unlike JSON, CBOR requires no escaping for binary
        content.

        **See also** **appendByteString** (), **QCborStreamReader::isByteArray**
        (), and **QCborStreamReader::readByteArray** ().
        """
        ...

    @typing.overload
    def append(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#append-4

        **void QCborStreamWriter::append(QLatin1String str )**

        This is an overloaded function.

        Appends the text string **str** to the stream, creating a CBOR Text
        String value. **QCborStreamWriter**  will attempt to write the entire
        string in one chunk.

        The following example appends a simple string to the stream:

        writer.append(QLatin1String("Hello, World"));

        **Performance note** : CBOR requires that all Text Strings be encoded in
        UTF-8, so this function will iterate over the characters in the string
        to determine whether the contents are US-ASCII or not. If the string is
        found to contain characters outside of US-ASCII, it will allocate memory
        and convert to UTF-8. If this check is unnecessary, use
        **appendTextString** () instead.

        **See also** **QCborStreamReader::isString** () and
        **QCborStreamReader::readString** ().
        """
        ...

    @typing.overload
    def append(self, d: float) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#append-5

        **void QCborStreamWriter::append(QStringView str )**

        This is an overloaded function.

        Appends the text string **str** to the stream, creating a CBOR Text
        String value. **QCborStreamWriter**  will attempt to write the entire
        string in one chunk.

        The following example writes an arbitrary **QString**  to the stream:

        void writeString(**QCborStreamWriter**  &writer, const **QString**
        &str)
               {
                   writer.append(str);
               }

        **See also** **QCborStreamReader::isString** () and
        **QCborStreamReader::readString** ().
        """
        ...

    @typing.overload
    def append(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#append-6

        **void QCborStreamWriter::append(QCborTag tag )**

        This is an overloaded function.

        Appends the CBOR tag **tag** to the stream, creating a CBOR Tag value.
        All tags must be followed by another type which they provide meaning
        for.

        In the following example, we append a CBOR Tag 36 (Regular Expression)
        and a **QRegularExpression** 's pattern to the stream:

        void writeRxPattern(**QCborStreamWriter**  &writer, const
        **QRegularExpression**  &rx)
               {
        writer.append(**QCborTag** (36));
        writer.append(rx.pattern());
               }

        **See also** **QCborStreamReader::isTag** () and
        **QCborStreamReader::toTag** ().
        """
        ...

    def device(self) -> QIODevice:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#device

        **QIODevice *QCborStreamWriter::device() const**

        Returns the **QIODevice**  that this **QCborStreamWriter**  object is
        writing to. The device must have previously been set with either the
        constructor or with **setDevice** ().

        If this object was created by writing to a **QByteArray** , this
        function will return an internal instance of **QBuffer** , which is
        owned by **QCborStreamWriter** .

        **See also** **setDevice** ().
        """
        ...

    def setDevice(self, device: QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamwriter.html#setDevice

        **void QCborStreamWriter::setDevice(QIODevice * device )**

        Replaces the device or byte array that this **QCborStreamWriter**
        object is writing to with **device**.

        **See also** **device** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QRegularExpression(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qregularexpression.html

    **Detailed Description**

    Regular expressions, or **regexps** , are a very powerful tool to handle
    strings and texts. This is useful in many contexts, e.g.,

    ValidationA regexp can test whether a substring meets some criteria, e.g. is
    an integer or contains no whitespace.
    SearchingA regexp provides more
    powerful pattern matching than simple substring matching, e.g., match one of
    the words **mail** , **letter** or **correspondence** , but none of the
    words **email** , **mailman** , **mailer** , **letterbox** , etc.
    Search
    and ReplaceA regexp can replace all occurrences of a substring with a
    different substring, e.g., replace all occurrences of **&** with **& amp;**
    except where the **&** is already followed by an **amp;**.
    String
    SplittingA regexp can be used to identify where a string should be split
    apart, e.g. splitting tab-delimited strings.

    This document is by no means a complete reference to pattern matching using
    regular expressions, and the following parts will require the reader to have
    some basic knowledge about Perl-like regular expressions and their pattern
    syntax.

    Good references about regular expressions include:

    * **Mastering Regular Expressions** (Third Edition) by Jeffrey E. F. Friedl,
    ISBN 0-596-52812-4;
      * the **pcrepattern(3)**  man page, describing the
    pattern syntax supported by PCRE (the reference implementation of Perl-
    compatible regular expressions);
      * the **Perl's regular expression
    documentation**  and the **Perl's regular expression tutorial** .

    **Introduction**

    QRegularExpression implements Perl-compatible regular expressions. It fully
    supports Unicode. For an overview of the regular expression syntax supported
    by QRegularExpression, please refer to the aforementioned pcrepattern(3) man
    page. A regular expression is made up of two things: a **pattern string**
    and a set of **pattern options** that change the meaning of the pattern
    string.

    You can set the pattern string by passing a string to the QRegularExpression
    constructor:

    **QRegularExpression**  re("a pattern");

    This sets the pattern string to `a pattern`. You can also use the
    **setPattern** () function to set a pattern on an existing
    QRegularExpression object:

    **QRegularExpression**  re;
        re.setPattern("another pattern");

    Note that due to C++ literal strings rules, you must escape all backslashes
    inside the pattern string with another backslash:

    // matches two digits followed by a space and a word
    **QRegularExpression**  re("\\\\d\\\\d \\\\w+");

        // matches a backslash
    **QRegularExpression**  re2("\\\\\\\\");

    Alternatively, you can use a **raw string literal** , in which case you
    don't need to escape backslashes in the pattern, all characters between
    `R"(...)"` are considered raw characters. As you can see in the following
    example, this simplifies writing patterns:

    // matches two digits followed by a space and a word
    **QRegularExpression**  re(R"(\\d\\d \\w+)");

    The **pattern** () function returns the pattern that is currently set for a
    QRegularExpression object:

    **QRegularExpression**  re("a third pattern");
        **QString**  pattern =
    re.pattern(); // pattern == "a third pattern"

    **Pattern Options**

    The meaning of the pattern string can be modified by setting one or more
    **pattern options**. For instance, it is possible to set a pattern to match
    case insensitively by setting the
    **QRegularExpression::CaseInsensitiveOption** .

    You can set the options by passing them to the QRegularExpression
    constructor, as in:

    // matches "Qt rocks", but also "QT rocks", "QT ROCKS", "qT rOcKs", etc.
    **QRegularExpression**  re("Qt rocks", **QRegularExpression**
    ::CaseInsensitiveOption);

    Alternatively, you can use the **setPatternOptions** () function on an
    existing QRegularExpressionObject:

    **QRegularExpression**  re("^\\\\d+$");
    re.setPatternOptions(**QRegularExpression** ::MultilineOption);
        // re
    matches any line in the subject string that contains only digits (but at
    least one)

    It is possible to get the pattern options currently set on a
    QRegularExpression object by using the **patternOptions** () function:

    **QRegularExpression**  re = **QRegularExpression** ("^two.*words$",
    **QRegularExpression** ::MultilineOption
    | **QRegularExpression** ::DotMatchesEverythingOption);
    **QRegularExpression** ::PatternOptions options = re.patternOptions();
    // options == QRegularExpression::MultilineOption |
    QRegularExpression::DotMatchesEverythingOption

    Please refer to the **QRegularExpression::PatternOption**  enum
    documentation for more information about each pattern option.

    **Match Type and Match Options**

    The last two arguments of the **match** () and the **globalMatch** ()
    functions set the match type and the match options. The match type is a
    value of the **QRegularExpression::MatchType**  enum; the "traditional"
    matching algorithm is chosen by using the **NormalMatch**  match type (the
    default). It is also possible to enable partial matching of the regular
    expression against a subject string: see the **partial matching**  section
    for more details.

    The match options are a set of one or more
    **QRegularExpression::MatchOption**  values. They change the way a specific
    match of a regular expression against a subject string is done. Please refer
    to the **QRegularExpression::MatchOption**  enum documentation for more
    details.

    **Normal Matching**

    In order to perform a match you can simply invoke the **match** () function
    passing a string to match against. We refer to this string as the **subject
    string**. The result of the **match** () function is a
    **QRegularExpressionMatch**  object that can be used to inspect the results
    of the match. For instance:

    // match two digits followed by a space and a word
    **QRegularExpression**  re("\\\\d\\\\d \\\\w+");
        **QRegularExpressionMatch**
    match = re.match("abc123 def");
        bool hasMatch = match.hasMatch(); //
    true

    If a match is successful, the (implicit) capturing group number 0 can be
    used to retrieve the substring matched by the entire pattern (see also the
    section about **extracting captured substrings** ):

    **QRegularExpression**  re("\\\\d\\\\d \\\\w+");
        **QRegularExpressionMatch**
    match = re.match("abc123 def");
        if (match.hasMatch()) {
    **QString**  matched = match.captured(0); // matched == "23 def"
            //
    ...
        }

    It's also possible to start a match at an arbitrary offset inside the
    subject string by passing the offset as an argument of the **match** ()
    function. In the following example `"12 abc"` is not matched because the
    match is started at offset 1:

    **QRegularExpression**  re("\\\\d\\\\d \\\\w+");
        **QRegularExpressionMatch**
    match = re.match("12 abc 45 def", 1);
        if (match.hasMatch()) {
    **QString**  matched = match.captured(0); // matched == "45 def"
            //
    ...
        }

    **Extracting captured substrings**

    The **QRegularExpressionMatch**  object contains also information about the
    substrings captured by the capturing groups in the pattern string. The
    **captured** () function will return the string captured by the n-th
    capturing group:

    **QRegularExpression**  re("^(\\\\d\\\\d)/(\\\\d\\\\d)/(\\\\d\\\\d\\\\d\\\\d)$");
    **QRegularExpressionMatch**  match = re.match("08/12/1985");
        if
    (match.hasMatch()) {
            **QString**  day = match.captured(1); // day ==
    "08"
            **QString**  month = match.captured(2); // month == "12"
    **QString**  year = match.captured(3); // year == "1985"
            // ...
    }

    Capturing groups in the pattern are numbered starting from 1, and the
    implicit capturing group 0 is used to capture the substring that matched the
    entire pattern.

    It's also possible to retrieve the starting and the ending offsets (inside
    the subject string) of each captured substring, by using the
    **capturedStart** () and the **capturedEnd** () functions:

    **QRegularExpression**  re("abc(\\\\d+)def");
        **QRegularExpressionMatch**
    match = re.match("XYZabc123defXYZ");
        if (match.hasMatch()) {
            int
    startOffset = match.capturedStart(1); // startOffset == 6
            int
    endOffset = match.capturedEnd(1); // endOffset == 9
            // ...
        }

    All of these functions have an overload taking a **QString**  as a parameter
    in order to extract **named** captured substrings. For instance:

    **QRegularExpression**
    re("^(?<date>\\\\d\\\\d)/(?<month>\\\\d\\\\d)/(?<year>\\\\d\\\\d\\\\d\\\\d)$");
    **QRegularExpressionMatch**  match = re.match("08/12/1985");
        if
    (match.hasMatch()) {
            **QString**  date = match.captured("date"); //
    date == "08"
            **QString**  month = match.captured("month"); // month
    == "12"
            **QString**  year = match.captured("year"); // year == 1985
    }

    **Global Matching**

    **Global matching** is useful to find all the occurrences of a given regular
    expression inside a subject string. Suppose that we want to extract all the
    words from a given string, where a word is a substring matching the pattern
    `\\w+`.

    **QRegularExpression::globalMatch**  returns a
    **QRegularExpressionMatchIterator** , which is a Java-like forward iterator
    that can be used to iterate over the results. For instance:

    **QRegularExpression**  re("(\\\\w+)");
    **QRegularExpressionMatchIterator**  i = re.globalMatch("the quick fox");

    Since it's a Java-like iterator, the **QRegularExpressionMatchIterator**
    will point immediately before the first result. Every result is returned as
    a **QRegularExpressionMatch**  object. The **hasNext** () function will
    return true if there's at least one more result, and **next** () will return
    the next result and advance the iterator. Continuing from the previous
    example:

    **QStringList**  words;
        while (i.hasNext()) {
    **QRegularExpressionMatch**  match = i.next();
            **QString**  word =
    match.captured(1);
            words << word;
        }
        // words contains "the",
    "quick", "fox"

    You can also use **peekNext** () to get the next result without advancing
    the iterator.

    It is also possible to simply use the result of
    **QRegularExpression::globalMatch**  in a range-based for loop, for instance
    like this:

    // using a raw string literal, R"(raw_characters)", to be able to use "\\w"
    // without having to escape the backslash as "\\\\w"
    **QRegularExpression**  re(R"(\\w+)");
        **QString**  subject("the quick
    fox");
        for (const **QRegularExpressionMatch**  &match :
    re.globalMatch(subject)) {
            // ...
        }

    It is possible to pass a starting offset and one or more match options to
    the **globalMatch** () function, exactly like normal matching with **match**
    ().

    **Partial Matching**

    A **partial match** is obtained when the end of the subject string is
    reached, but more characters are needed to successfully complete the match.
    Note that a partial match is usually much more inefficient than a normal
    match because many optimizations of the matching algorithm cannot be
    employed.

    A partial match must be explicitly requested by specifying a match type of
    **PartialPreferCompleteMatch**  or **PartialPreferFirstMatch**  when calling
    **QRegularExpression::match**  or **QRegularExpression::globalMatch** . If a
    partial match is found, then calling the **hasMatch** () function on the
    **QRegularExpressionMatch**  object returned by **match** () will return
    `false`, but **hasPartialMatch** () will return `true`.

    When a partial match is found, no captured substrings are returned, and the
    (implicit) capturing group 0 corresponding to the whole match captures the
    partially matched substring of the subject string.

    Note that asking for a partial match can still lead to a complete match, if
    one is found; in this case, **hasMatch** () will return `true` and
    **hasPartialMatch** () `false`. It never happens that a
    **QRegularExpressionMatch**  reports both a partial and a complete match.

    Partial matching is mainly useful in two scenarios: validating user input in
    real time and incremental/multi-segment matching.

    **Validating user input**

    Suppose that we would like the user to input a date in a specific format,
    for instance "MMM dd, yyyy". We can check the input validity with a pattern
    like:

    `^(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) \\d\\d?, \\d\\d\\d\\d$`

    (This pattern doesn't catch invalid days, but let's keep it for the
    example's purposes).

    We would like to validate the input with this regular expression **while**
    the user is typing it, so that we can report an error in the input as soon
    as it is committed (for instance, the user typed the wrong key). In order to
    do so we must distinguish three cases:

    * the input cannot possibly match the regular expression;
      * the input does
    match the regular expression;
      * the input does not match the regular
    expression right now, but it will if more characters will be added to it.

    Note that these three cases represent exactly the possible states of a
    **QValidator**  (see the **QValidator::State**  enum).

    In particular, in the last case we want the regular expression engine to
    report a partial match: we are successfully matching the pattern against the
    subject string but the matching cannot continue because the end of the
    subject is encountered. Notice, however, that the matching algorithm should
    continue and try all possibilities, and in case a complete (non-partial)
    match is found, then this one should be reported, and the input string
    accepted as fully valid.

    This behavior is implemented by the **PartialPreferCompleteMatch**  match
    type. For instance:

    **QString**  pattern("^(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)
    \\\\d\\\\d?, \\\\d\\\\d\\\\d\\\\d$");
        **QRegularExpression**  re(pattern);
    **QString**  input("Jan 21,");
        **QRegularExpressionMatch**  match =
    re.match(input, 0, **QRegularExpression** ::PartialPreferCompleteMatch);
    bool hasMatch = match.hasMatch(); // false
        bool hasPartialMatch =
    match.hasPartialMatch(); // true

    If matching the same regular expression against the subject string leads to
    a complete match, it is reported as usual:

    **QString**  input("Dec 8, 1985");
        **QRegularExpressionMatch**  match =
    re.match(input, 0, **QRegularExpression** ::PartialPreferCompleteMatch);
    bool hasMatch = match.hasMatch(); // true
        bool hasPartialMatch =
    match.hasPartialMatch(); // false

    Another example with a different pattern, showing the behavior of preferring
    a complete match over a partial one:

    **QRegularExpression**  re("abc\\\\w+X|def");
        **QRegularExpressionMatch**
    match = re.match("abcdef", 0, **QRegularExpression**
    ::PartialPreferCompleteMatch);
        bool hasMatch = match.hasMatch(); // true
    bool hasPartialMatch = match.hasPartialMatch(); // false
        **QString**
    captured = match.captured(0); // captured == "def"

    In this case, the subpattern `abc\\\\w+X` partially matches the subject
    string; however, the subpattern `def` matches the subject string completely,
    and therefore a complete match is reported.

    If multiple partial matches are found when matching (but no complete match),
    then the **QRegularExpressionMatch**  object will report the first one that
    is found. For instance:

    **QRegularExpression**  re("abc\\\\w+X|defY");
        **QRegularExpressionMatch**
    match = re.match("abcdef", 0, **QRegularExpression**
    ::PartialPreferCompleteMatch);
        bool hasMatch = match.hasMatch(); //
    false
        bool hasPartialMatch = match.hasPartialMatch(); // true
    **QString**  captured = match.captured(0); // captured == "abcdef"

    **Incremental/multi-segment matching**

    Incremental matching is another use case of partial matching. Suppose that
    we want to find the occurrences of a regular expression inside a large text
    (that is, substrings matching the regular expression). In order to do so we
    would like to "feed" the large text to the regular expression engines in
    smaller chunks. The obvious problem is what happens if the substring that
    matches the regular expression spans across two or more chunks.

    In this case, the regular expression engine should report a partial match,
    so that we can match again adding new data and (eventually) get a complete
    match. This implies that the regular expression engine may assume that there
    are other characters **beyond the end** of the subject string. This is not
    to be taken literally -- the engine will never try to access any character
    after the last one in the subject.

    QRegularExpression implements this behavior when using the
    **PartialPreferFirstMatch**  match type. This match type reports a partial
    match as soon as it is found, and other match alternatives are not tried
    (even if they could lead to a complete match). For instance:

    **QRegularExpression**  re("abc|ab");
        **QRegularExpressionMatch**  match
    = re.match("ab", 0, **QRegularExpression** ::PartialPreferFirstMatch);
    bool hasMatch = match.hasMatch(); // false
        bool hasPartialMatch =
    match.hasPartialMatch(); // true

    This happens because when matching the first branch of the alternation
    operator a partial match is found, and therefore matching stops, without
    trying the second branch. Another example:

    **QRegularExpression**  re("abc(def)?");
        **QRegularExpressionMatch**
    match = re.match("abc", 0, **QRegularExpression**
    ::PartialPreferFirstMatch);
        bool hasMatch = match.hasMatch(); // false
    bool hasPartialMatch = match.hasPartialMatch(); // true

    This shows what could seem a counterintuitive behavior of quantifiers: since
    `?` is greedy, then the engine tries first to continue the match after
    having matched `"abc"`; but then the matching reaches the end of the subject
    string, and therefore a partial match is reported. This is even more
    surprising in the following example:

    **QRegularExpression**  re("(abc)*");
        **QRegularExpressionMatch**  match
    = re.match("abc", 0, **QRegularExpression** ::PartialPreferFirstMatch);
    bool hasMatch = match.hasMatch(); // false
        bool hasPartialMatch =
    match.hasPartialMatch(); // true

    It's easy to understand this behavior if we remember that the engine expects
    the subject string to be only a substring of the whole text we're looking
    for a match into (that is, how we said before, that the engine assumes that
    there are other characters beyond the end of the subject string).

    Since the `*` quantifier is greedy, then reporting a complete match could be
    an error, because after the current subject `"abc"` there may be other
    occurrences of `"abc"`. For instance, the complete text could have been
    "abcabcX", and therefore the **right** match to report (in the complete
    text) would have been `"abcabc"`; by matching only against the leading
    `"abc"` we instead get a partial match.

    **Error Handling**

    It is possible for a QRegularExpression object to be invalid because of
    syntax errors in the pattern string. The **isValid** () function will return
    true if the regular expression is valid, or false otherwise:

    **QRegularExpression**  invalidRe("(unmatched|parenthesis");
        bool
    isValid = invalidRe.isValid(); // false

    You can get more information about the specific error by calling the
    **errorString** () function; moreover, the **patternErrorOffset** ()
    function will return the offset inside the pattern string

    **QRegularExpression**  invalidRe("(unmatched|parenthesis");
        if
    (!invalidRe.isValid()) {
            **QString**  errorString =
    invalidRe.errorString(); // errorString == "missing )"
            int
    errorOffset = invalidRe.patternErrorOffset(); // errorOffset == 22
    // ...
        }

    If a match is attempted with an invalid QRegularExpression, then the
    returned **QRegularExpressionMatch**  object will be invalid as well (that
    is, its **isValid** () function will return false). The same applies for
    attempting a global match.

    **Unsupported Perl-compatible Regular Expressions Features**

    QRegularExpression does not support all the features available in Perl-
    compatible regular expressions. The most notable one is the fact that
    duplicated names for capturing groups are not supported, and using them can
    lead to undefined behavior.

    This may change in a future version of Qt.

    **Debugging Code that Uses QRegularExpression**

    QRegularExpression internally uses a just in time compiler (JIT) to optimize
    the execution of the matching algorithm. The JIT makes extensive usage of
    self-modifying code, which can lead debugging tools such as Valgrind to
    crash. You must enable all checks for self-modifying code if you want to
    debug programs using QRegularExpression (for instance, Valgrind's `--smc-
    check` command line option). The downside of enabling such checks is that
    your program will run considerably slower.

    To avoid that, the JIT is disabled by default if you compile Qt in debug
    mode. It is possible to override the default and enable or disable the JIT
    usage (both in debug or release mode) by setting the `QT_ENABLE_REGEXP_JIT`
    environment variable to a non-zero or zero value respectively.

    **See also** **QRegularExpressionMatch**  and
    **QRegularExpressionMatchIterator** .
    """

    class WildcardConversionOption(enum.Flag):
        DefaultWildcardConversion: QRegularExpression = ...
        UnanchoredWildcardConversion: QRegularExpression = ...

    class MatchOption(enum.Flag):
        NoMatchOption: QRegularExpression = ...
        AnchorAtOffsetMatchOption: QRegularExpression = ...
        DontCheckSubjectStringMatchOption: QRegularExpression = ...

    class MatchType(enum.Enum):
        NormalMatch: QRegularExpression = ...
        PartialPreferCompleteMatch: QRegularExpression = ...
        PartialPreferFirstMatch: QRegularExpression = ...
        NoMatch: QRegularExpression = ...

    class PatternOption(enum.Flag):
        NoPatternOption: QRegularExpression = ...
        CaseInsensitiveOption: QRegularExpression = ...
        DotMatchesEverythingOption: QRegularExpression = ...
        MultilineOption: QRegularExpression = ...
        ExtendedPatternSyntaxOption: QRegularExpression = ...
        InvertedGreedinessOption: QRegularExpression = ...
        DontCaptureOption: QRegularExpression = ...
        UseUnicodePropertiesOption: QRegularExpression = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qregularexpression.html#QRegularExpression

        **QRegularExpression::QRegularExpression()**

        Constructs a QRegularExpression object with an empty pattern and no
        pattern options.

        **See also** **setPattern** () and **setPatternOptions** ().
        """
        ...

    @typing.overload
    def __init__(
        self, pattern: str, options: "QRegularExpression.PatternOption" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qregularexpression.html#QRegularExpression-1

        **QRegularExpression::QRegularExpression(const QString & pattern ,
        QRegularExpression::PatternOptions options = NoPatternOption)**

        Constructs a QRegularExpression object using the given **pattern** as
        pattern and the **options** as the pattern options.

        **See also** **setPattern** () and **setPatternOptions** ().
        """
        ...

    @typing.overload
    def __init__(self, re: "QRegularExpression") -> None:
        """
        https://doc.qt.io/qt-6/qregularexpression.html#QRegularExpression-2

        **QRegularExpression::QRegularExpression(const QRegularExpression & re
        )**

        Constructs a QRegularExpression object as a copy of **re**.

        **See also** **operator=** ().
        """
        ...

    @staticmethod
    def fromWildcard(
        pattern: str,
        cs: Qt.CaseSensitivity = ...,
        options: "QRegularExpression.WildcardConversionOption" = ...,
    ) -> "QRegularExpression":
        """
        https://doc.qt.io/qt-6/qregularexpression.html#fromWildcard

        **[static, since 6.0] QRegularExpression
        QRegularExpression::fromWildcard(QStringView pattern ,
        Qt::CaseSensitivity cs = Qt::CaseInsensitive,
        QRegularExpression::WildcardConversionOptions options =
        DefaultWildcardConversion)**

        Returns a regular expression of the glob pattern **pattern**. The
        regular expression will be case sensitive if **cs** is
        **Qt::CaseSensitive** , and converted according to **options**.

        Equivalent to

        auto reOptions = cs == Qt::CaseSensitive ? **QRegularExpression**
        ::NoPatternOption :
        **QRegularExpression** ::CaseInsensitiveOption;
            return
        **QRegularExpression** (wildcardToRegularExpression(str, options),
        reOptions);

        This function was introduced in Qt 6.0.
        """
        ...

    @staticmethod
    def anchoredPattern(expression: str) -> str:
        """
        https://doc.qt.io/qt-6/qregularexpression.html#anchoredPattern

        **[static, since 5.15] QString
        QRegularExpression::anchoredPattern(QStringView expression )**

        Returns the **expression** wrapped between the `\\A` and `\\z` anchors to
        be used for exact matching.

        This function was introduced in Qt 5.15.
        """
        ...

    @staticmethod
    def wildcardToRegularExpression(
        str: str, options: "QRegularExpression.WildcardConversionOption" = ...
    ) -> str:
        """
        https://doc.qt.io/qt-6/qregularexpression.html#wildcardToRegularExpressi
        on

        **[static, since 5.15] QString
        QRegularExpression::wildcardToRegularExpression(QStringView pattern ,
        QRegularExpression::WildcardConversionOptions options =
        DefaultWildcardConversion)**

        Returns a regular expression representation of the given glob
        **pattern**. The transformation is targeting file path globbing, which
        means in particular that path separators receive special treatment. This
        implies that it is not just a basic translation from "*" to ".*".

        **QString**  wildcard = **QRegularExpression**
        ::wildcardToRegularExpression("*.jpeg");
            // Will match files with
        names like:
            //    foo.jpeg
            //    f_o_o.jpeg
            //    föö.jpeg

        By default, the returned regular expression is fully anchored. In other
        words, there is no need of calling **anchoredPattern** () again on the
        result. To get an a regular expression that is not anchored, pass
        **UnanchoredWildcardConversion**  as the conversion **options**.

        This implementation follows closely the definition of wildcard for glob
        patterns:

        **c** Any character represents itself apart from those mentioned below.
        Thus **c** matches the character **c**.
        **?** Matches any single
        character. It is the same as **.** in full regexps.
        ***** Matches zero
        or more of any characters. It is the same as **.*** in full regexps.
        **[abc]** Matches one character given in the bracket.
        **[a-c]**
        Matches one character from the range given in the bracket.
        **[!abc]**
        Matches one character that is not given in the bracket. It is the same
        as **[^abc]** in full regexp.
        **[!a-c]** Matches one character that is
        not from the range given in the bracket. It is the same as **[^a-c]** in
        full regexp.

        **Note:** The backslash (\\\\) character is **not** an escape char in this
        context. In order to match one of the special characters, place it in
        square brackets (for example, `[?]`).

        More information about the implementation can be found in:

        * **The Wikipedia Glob article**
          * `man 7 glob`

        This function was introduced in Qt 5.15.

        **See also** **escape** ().
        """
        ...

    def __hash__(self) -> int:
        ...

    def optimize(self) -> None:
        """
        https://doc.qt.io/qt-6/qregularexpression.html#optimize

        **[since 5.4] void QRegularExpression::optimize() const**

        Compiles the pattern immediately, including JIT compiling it (if the JIT
        is enabled) for optimization.

        This function was introduced in Qt 5.4.

        **See also** **isValid** () and **Debugging Code that Uses
        QRegularExpression** .
        """
        ...

    def namedCaptureGroups(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qregularexpression.html#namedCaptureGroups

        **[since 5.1] QStringList QRegularExpression::namedCaptureGroups()
        const**

        Returns a list of **captureCount** () + 1 elements, containing the names
        of the named capturing groups in the pattern string. The list is sorted
        such that the element of the list at position `i` is the name of the
        `i`-th capturing group, if it has a name, or an empty string if that
        capturing group is unnamed.

        For instance, given the regular expression

        (?<day>\\d\\d)-(?<month>\\d\\d)-(?<year>\\d\\d\\d\\d) (\\w+) (?<name>\\w+)

        namedCaptureGroups() will return the following list:

        ("", "day", "month", "year", "", "name")

        which corresponds to the fact that the capturing group #0 (corresponding
        to the whole match) has no name, the capturing group #1 has name "day",
        the capturing group #2 has name "month", etc.

        If the regular expression is not valid, returns an empty list.

        This function was introduced in Qt 5.1.

        **See also** **isValid** (), **QRegularExpressionMatch::captured** (),
        and **QString::isEmpty** ().
        """
        ...

    @staticmethod
    def escape(str: str) -> str:
        """
        https://doc.qt.io/qt-6/qregularexpression.html#escape

        **[static, since 5.15] QString QRegularExpression::escape(QStringView
        str )**

        Escapes all characters of **str** so that they no longer have any
        special meaning when used as a regular expression pattern string, and
        returns the escaped string. For instance:

        **QString**  escaped = **QRegularExpression** ::escape("a(x) = f(x) +
        g(x)");
            // escaped == "a\\\\(x\\\\)\\\\ \\\\=\\\\ f\\\\(x\\\\)\\\\ \\\\+\\\\ g\\\\(x\\\\)"

        This is very convenient in order to build patterns from arbitrary
        strings:

        **QString**  pattern = "(" + **QRegularExpression** ::escape(name) +
        "|" + **QRegularExpression** ::escape(nickname) + ")";
        **QRegularExpression**  re(pattern);

        **Note:** This function implements Perl's quotemeta algorithm and
        escapes with a backslash all characters in **str** , except for the
        characters in the `[A-Z]`, `[a-z]` and `[0-9]` ranges, as well as the
        underscore (`_`) character. The only difference with Perl is that a
        literal NUL inside **str** is escaped with the sequence `"\\\\0"`
        (backslash + `'0'`), instead of `"\\\\\\0"` (backslash + `NUL`).

        This function was introduced in Qt 5.15.
        """
        ...

    def globalMatch(
        self,
        subjectView: str,
        offset: int = ...,
        matchType: "QRegularExpression.MatchType" = ...,
        matchOptions: "QRegularExpression.MatchOption" = ...,
    ) -> "QRegularExpressionMatchIterator":
        """
        https://doc.qt.io/qt-6/qregularexpression.html#globalMatch

        **QRegularExpressionMatchIterator QRegularExpression::globalMatch(const
        QString & subject , qsizetype offset = 0, QRegularExpression::MatchType
        matchType = NormalMatch, QRegularExpression::MatchOptions matchOptions =
        NoMatchOption) const**

        Attempts to perform a global match of the regular expression against the
        given **subject** string, starting at the position **offset** inside the
        subject, using a match of type **matchType** and honoring the given
        **matchOptions**.

        The returned **QRegularExpressionMatchIterator**  is positioned before
        the first match result (if any).

        **Note:** The data referenced by **subject** should remain valid as long
        as there are **QRegularExpressionMatch**  objects using it. At the
        moment Qt makes a (shallow) copy of the data, but this behavior may
        change in a future version of Qt.

        **See also** **QRegularExpressionMatchIterator**  and **global
        matching** .
        """
        ...

    def match(
        self,
        subjectView: str,
        offset: int = ...,
        matchType: "QRegularExpression.MatchType" = ...,
        matchOptions: "QRegularExpression.MatchOption" = ...,
    ) -> "QRegularExpressionMatch":
        """
        https://doc.qt.io/qt-6/qregularexpression.html#match

        **QRegularExpressionMatch QRegularExpression::match(const QString &
        subject , qsizetype offset = 0, QRegularExpression::MatchType matchType
        = NormalMatch, QRegularExpression::MatchOptions matchOptions =
        NoMatchOption) const**

        Attempts to match the regular expression against the given **subject**
        string, starting at the position **offset** inside the subject, using a
        match of type **matchType** and honoring the given **matchOptions**.

        The returned **QRegularExpressionMatch**  object contains the results of
        the match.

        **Note:** The data referenced by **subject** should remain valid as long
        as there are **QRegularExpressionMatch**  objects using it. At the
        moment Qt makes a (shallow) copy of the data, but this behavior may
        change in a future version of Qt.

        **See also** **QRegularExpressionMatch**  and **normal matching** .
        """
        ...

    def captureCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qregularexpression.html#captureCount

        **int QRegularExpression::captureCount() const**

        Returns the number of capturing groups inside the pattern string, or -1
        if the regular expression is not valid.

        **Note:** The implicit capturing group 0 is **not** included in the
        returned number.

        **See also** **isValid** ().
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qregularexpression.html#errorString

        **QString QRegularExpression::errorString() const**

        Returns a textual description of the error found when checking the
        validity of the regular expression, or "no error" if no error was found.

        **See also** **isValid** () and **patternErrorOffset** ().
        """
        ...

    def patternErrorOffset(self) -> int:
        """
        https://doc.qt.io/qt-6/qregularexpression.html#patternErrorOffset

        **qsizetype QRegularExpression::patternErrorOffset() const**

        Returns the offset, inside the pattern string, at which an error was
        found when checking the validity of the regular expression. If no error
        was found, then -1 is returned.

        **See also** **pattern** (), **isValid** (), and **errorString** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qregularexpression.html#isValid

        **bool QRegularExpression::isValid() const**

        Returns `true` if the regular expression is a valid regular expression
        (that is, it contains no syntax errors, etc.), or false otherwise. Use
        **errorString** () to obtain a textual description of the error.

        **See also** **errorString** () and **patternErrorOffset** ().
        """
        ...

    def setPattern(self, pattern: str) -> None:
        """
        https://doc.qt.io/qt-6/qregularexpression.html#setPattern

        **void QRegularExpression::setPattern(const QString & pattern )**

        Sets the pattern string of the regular expression to **pattern**. The
        pattern options are left unchanged.

        **See also** **pattern** () and **setPatternOptions** ().
        """
        ...

    def pattern(self) -> str:
        """
        https://doc.qt.io/qt-6/qregularexpression.html#pattern

        **QString QRegularExpression::pattern() const**

        Returns the pattern string of the regular expression.

        **See also** **setPattern** () and **patternOptions** ().
        """
        ...

    def swap(self, re: "QRegularExpression") -> None:
        """
        https://doc.qt.io/qt-6/qregularexpression.html#swap

        **void QRegularExpression::swap(QRegularExpression & other )**

        Swaps the regular expression **other** with this regular expression.
        This operation is very fast and never fails.
        """
        ...

    def __repr__(self) -> str:
        ...

    def setPatternOptions(self, options: "QRegularExpression.PatternOption") -> None:
        """
        https://doc.qt.io/qt-6/qregularexpression.html#setPatternOptions

        **void
        QRegularExpression::setPatternOptions(QRegularExpression::PatternOptions
        options )**

        Sets the given **options** as the pattern options of the regular
        expression. The pattern string is left unchanged.

        **See also** **patternOptions** () and **setPattern** ().
        """
        ...

    def patternOptions(self) -> "QRegularExpression.PatternOption":
        """
        https://doc.qt.io/qt-6/qregularexpression.html#patternOptions

        **QRegularExpression::PatternOptions
        QRegularExpression::patternOptions() const**

        Returns the pattern options for the regular expression.

        **See also** **setPatternOptions** () and **pattern** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QResource(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qresource.html

    **Detailed Description**

    QResource is an object that represents a set of data (and possibly children)
    relating to a single resource entity. QResource gives direct access to the
    bytes in their raw format. In this way direct access allows reading data
    without buffer copying or indirection. Indirection is often useful when
    interacting with the resource entity as if it is a file, this can be
    achieved with **QFile** . The data and children behind a QResource are
    normally compiled into an application/library, but it is also possible to
    load a resource at runtime. When loaded at run time the resource file will
    be loaded as one big set of data and then given out in pieces via references
    into the resource tree.

    A QResource can either be loaded with an absolute path, either treated as a
    file system rooted with a `/` character, or in resource notation rooted with
    a `:` character. A relative resource can also be opened which will be found
    in the list of paths returned by **QDir::searchPaths** ().

    A QResource that is representing a file will have data backing it, this data
    can possibly be compressed, in which case **qUncompress** () must be used to
    access the real data; this happens implicitly when accessed through a
    **QFile** . A QResource that is representing a directory will have only
    children and no data.

    **Dynamic Resource Loading**

    A resource can be left out of an application's binary and loaded when it is
    needed at run-time by using the **registerResource** () function. The
    resource file passed into **registerResource** () must be a binary resource
    as created by rcc. Further information about binary resources can be found
    in **The Qt Resource System**  documentation.

    This can often be useful when loading a large set of application icons that
    may change based on a setting, or that can be edited by a user and later
    recreated. The resource is immediately loaded into memory, either as a
    result of a single file read operation, or as a memory mapped file.

    This approach can prove to be a significant performance gain as only a
    single file will be loaded, and pieces of data will be given out via the
    path requested in **setFileName** ().

    The **unregisterResource** () function removes a reference to a particular
    file. If there are QResource objects that currently reference resources
    related to the unregistered file, they will continue to be valid but the
    resource file itself will be removed from the resource roots, and thus no
    further QResource can be created pointing into this resource data. The
    resource itself will be unmapped from memory when the last QResource that
    points to it is destroyed.

    **See also** **The Qt Resource System** , **QFile** , **QDir** , and
    **QFileInfo** .
    """

    class Compression(enum.Enum):
        NoCompression: QResource = ...
        ZlibCompression: QResource = ...
        ZstdCompression: QResource = ...

    def __init__(self, fileName: str = ..., locale: QLocale = ...) -> None:
        """
        https://doc.qt.io/qt-6/qresource.html#QResource

        **QResource::QResource(const QString & file = QString(), const QLocale &
        locale = QLocale())**

        Constructs a QResource pointing to **file**. **locale** is used to load
        a specific localization of a resource data.

        **See also** **QFileInfo** , **QDir::searchPaths** (), **setFileName**
        (), and **setLocale** ().
        """
        ...

    def uncompressedData(self) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qresource.html#uncompressedData

        **[since 5.15] QByteArray QResource::uncompressedData() const**

        Returns the resource data, decompressing it first, if the data was
        stored compressed. If the resource is a directory or an error occurs
        while decompressing, a null **QByteArray**  is returned.

        **Note:** If the data was compressed, this function will decompress
        every time it is called. The result is not cached between calls.

        This function was introduced in Qt 5.15.

        **See also** **uncompressedSize** (), **size** (),
        **compressionAlgorithm** (), and **isFile** ().
        """
        ...

    def uncompressedSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qresource.html#uncompressedSize

        **[since 5.15] qint64 QResource::uncompressedSize() const**

        Returns the size of the data in this resource. If the data was not
        compressed, this function returns the same as **size** (). If it was,
        then this function extracts the size of the original uncompressed data
        from the stored stream.

        This function was introduced in Qt 5.15.

        **See also** **size** (), **uncompressedData** (), and **isFile** ().
        """
        ...

    def compressionAlgorithm(self) -> "QResource.Compression":
        """
        https://doc.qt.io/qt-6/qresource.html#compressionAlgorithm

        **[since 5.13] QResource::Compression QResource::compressionAlgorithm()
        const**

        Returns the compression type that this resource is compressed with, if
        any. If it is not compressed, this function returns
        **QResource::NoCompression** .

        If this function returns **QResource::ZlibCompression** , you may
        decompress the data using the **qUncompress** () function. Up until Qt
        5.13, this was the only possible compression algorithm.

        If this function returns **QResource::ZstdCompression** , you need to
        use the Zstandard library functions (`<zstd.h>` header). Qt does not
        provide a wrapper.

        See **Zstandard manual** .

        This function was introduced in Qt 5.13.

        **See also** **data** () and **isFile** ().
        """
        ...

    def lastModified(self) -> QDateTime:
        """
        https://doc.qt.io/qt-6/qresource.html#lastModified

        **[since 5.8] QDateTime QResource::lastModified() const**

        Returns the date and time when the file was last modified before
        packaging into a resource.

        This function was introduced in Qt 5.8.
        """
        ...

    def isFile(self) -> bool:
        """
        https://doc.qt.io/qt-6/qresource.html#isFile

        **[protected] bool QResource::isFile() const**

        Returns `true` if the resource represents a file and thus has data
        backing it, false if it represents a directory.

        **See also** **isDir** ().
        """
        ...

    def isDir(self) -> bool:
        """
        https://doc.qt.io/qt-6/qresource.html#isDir

        **[protected] bool QResource::isDir() const**

        Returns `true` if the resource represents a directory and thus may have
        **children** () in it, false if it represents a file.

        **See also** **isFile** ().
        """
        ...

    def children(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qresource.html#children

        **[protected] QStringList QResource::children() const**

        Returns a list of all resources in this directory, if the resource
        represents a file the list will be empty.

        **See also** **isDir** ().
        """
        ...

    @staticmethod
    def unregisterResourceData(rccData: bytes, mapRoot: str = ...) -> bool:
        ...

    @staticmethod
    def unregisterResource(rccFileName: str, mapRoot: str = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qresource.html#unregisterResource

        **[static] bool QResource::unregisterResource(const QString &
        rccFileName , const QString & mapRoot = QString())**

        Unregisters the resource with the given **rccFileName** at the location
        in the resource tree specified by **mapRoot** , and returns `true` if
        the resource is successfully unloaded and no references exist for the
        resource; otherwise returns `false`.

        **See also** **registerResource** ().
        """
        ...

    @staticmethod
    def registerResourceData(rccData: bytes, mapRoot: str = ...) -> bool:
        ...

    @staticmethod
    def registerResource(rccFileName: str, mapRoot: str = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qresource.html#registerResource

        **[static] bool QResource::registerResource(const QString & rccFileName
        , const QString & mapRoot = QString())**

        Registers the resource with the given **rccFileName** at the location in
        the resource tree specified by **mapRoot** , and returns `true` if the
        file is successfully opened; otherwise returns `false`.

        **See also** **unregisterResource** ().
        """
        ...

    def size(self) -> int:
        """
        https://doc.qt.io/qt-6/qresource.html#size

        **qint64 QResource::size() const**

        Returns the size of the stored data backing the resource.

        If the resource is compressed, this function returns the size of the
        compressed data. See **uncompressedSize** () for the uncompressed size.

        **See also** **data** (), **uncompressedSize** (), and **isFile** ().
        """
        ...

    def setLocale(self, locale: QLocale) -> None:
        """
        https://doc.qt.io/qt-6/qresource.html#setLocale

        **void QResource::setLocale(const QLocale & locale )**

        Sets a **QResource**  to only load the localization of resource to for
        **locale**. If a resource for the specific locale is not found then the
        C locale is used.

        **See also** **locale** () and **setFileName** ().
        """
        ...

    def setFileName(self, file: str) -> None:
        """
        https://doc.qt.io/qt-6/qresource.html#setFileName

        **void QResource::setFileName(const QString & file )**

        Sets a **QResource**  to point to **file**. **file** can either be
        absolute, in which case it is opened directly, if relative then the file
        will be tried to be found in **QDir::searchPaths** ().

        **See also** **fileName** () and **absoluteFilePath** ().
        """
        ...

    def locale(self) -> QLocale:
        """
        https://doc.qt.io/qt-6/qresource.html#locale

        **QLocale QResource::locale() const**

        Returns the locale used to locate the data for the **QResource** .

        **See also** **setLocale** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qresource.html#isValid

        **bool QResource::isValid() const**

        Returns `true` if the resource really exists in the resource hierarchy,
        false otherwise.
        """
        ...

    def fileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qresource.html#fileName

        **QString QResource::fileName() const**

        Returns the full path to the file that this **QResource**  represents as
        it was passed.

        **See also** **setFileName** () and **absoluteFilePath** ().
        """
        ...

    def data(self) -> bytes:
        """
        https://doc.qt.io/qt-6/qresource.html#data

        **const uchar *QResource::data() const**

        Returns direct access to a segment of read-only data, that this resource
        represents. If the resource is compressed, the data returned is also
        compressed. The caller must then decompress the data or use
        **uncompressedData** (). If the resource is a directory, `nullptr` is
        returned.

        **See also** **uncompressedData** (), **size** (), and **isFile** ().
        """
        ...

    def absoluteFilePath(self) -> str:
        """
        https://doc.qt.io/qt-6/qresource.html#absoluteFilePath

        **QString QResource::absoluteFilePath() const**

        Returns the real path that this **QResource**  represents, if the
        resource was found via the **QDir::searchPaths** () it will be indicated
        in the path.

        **See also** **fileName** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QToolButton(QAbstractButton):
    """
    https://doc.qt.io/qt-6/qtoolbutton.html

    **Detailed Description**

    A tool button is a special button that provides quick-access to specific
    commands or options. As opposed to a normal command button, a tool button
    usually doesn't show a text label, but shows an icon instead.

    Tool buttons are normally created when new **QAction**  instances are
    created with **QToolBar::addAction** () or existing actions are added to a
    toolbar with **QToolBar::addAction** (). It is also possible to construct
    tool buttons in the same way as any other widget, and arrange them alongside
    other widgets in layouts.

    One classic use of a tool button is to select tools; for example, the "pen"
    tool in a drawing program. This would be implemented by using a QToolButton
    as a toggle button (see **setCheckable** ()).

    QToolButton supports auto-raising. In auto-raise mode, the button draws a 3D
    frame only when the mouse points at it. The feature is automatically turned
    on when a button is used inside a **QToolBar** . Change it with
    **setAutoRaise** ().

    A tool button's icon is set as **QIcon** . This makes it possible to specify
    different pixmaps for the disabled and active state. The disabled pixmap is
    used when the button's functionality is not available. The active pixmap is
    displayed when the button is auto-raised because the mouse pointer is
    hovering over it.

    The button's look and dimension is adjustable with **setToolButtonStyle** ()
    and **setIconSize** (). When used inside a **QToolBar**  in a
    **QMainWindow** , the button automatically adjusts to **QMainWindow** 's
    settings (see **QMainWindow::setToolButtonStyle** () and
    **QMainWindow::setIconSize** ()). Instead of an icon, a tool button can also
    display an arrow symbol, specified with **arrowType** .

    A tool button can offer additional choices in a popup menu. The popup menu
    can be set using **setMenu** (). Use **setPopupMode** () to configure the
    different modes available for tool buttons with a menu set. The default mode
    is DelayedPopupMode which is sometimes used with the "Back" button in a web
    browser. After pressing and holding the button down for a while, a menu pops
    up showing a list of possible pages to jump to. The timeout is style
    dependent, see **QStyle::SH_ToolButton_PopupDelay** .

    ![Qt Assistant's toolbar with tool buttons](images/assistant-toolbar.png)
    Qt Assistant's toolbar contains tool buttons that are associated with
    actions used in other parts of the main window.

    **See also** **QPushButton** , **QToolBar** , **QMainWindow** , **QAction**
    , and **GUI Design Handbook: Push Button** .
    """

    class ToolButtonPopupMode(enum.Enum):
        DelayedPopup: QToolButton = ...
        MenuButtonPopup: QToolButton = ...
        InstantPopup: QToolButton = ...

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#QToolButton

        **QToolButton::QToolButton(QWidget * parent = nullptr)**

        Constructs an empty tool button with parent **parent**.
        """
        ...

    def checkStateSet(self) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#checkStateSet

        **[override virtual protected] void QToolButton::checkStateSet()**

        Reimplements: **QAbstractButton::checkStateSet** ().
        """
        ...

    def hitButton(self, pos: QtCore.QPoint) -> bool:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#hitButton

        **[override virtual protected] bool QToolButton::hitButton(const QPoint
        & pos ) const**

        Reimplements: **QAbstractButton::hitButton(const QPoint &pos) const** .
        """
        ...

    def nextCheckState(self) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#nextCheckState

        **[override virtual protected] void QToolButton::nextCheckState()**

        Reimplements: **QAbstractButton::nextCheckState** ().
        """
        ...

    def mouseReleaseEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#mouseReleaseEvent

        **[override virtual protected] void
        QToolButton::mouseReleaseEvent(QMouseEvent * e )**

        Reimplements: **QAbstractButton::mouseReleaseEvent** (QMouseEvent *e).
        """
        ...

    def changeEvent(self, a0: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#changeEvent

        **[override virtual protected] void QToolButton::changeEvent(QEvent * e
        )**

        Reimplements: **QAbstractButton::changeEvent** (QEvent *e).
        """
        ...

    def timerEvent(self, a0: QtCore.QTimerEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#timerEvent

        **[override virtual protected] void QToolButton::timerEvent(QTimerEvent
        * e )**

        Reimplements: **QAbstractButton::timerEvent** (QTimerEvent *e).
        """
        ...

    def leaveEvent(self, a0: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#leaveEvent

        **[override virtual protected] void QToolButton::leaveEvent(QEvent * e
        )**

        Reimplements: **QWidget::leaveEvent** (QEvent *event).
        """
        ...

    def enterEvent(self, a0: QtGui.QEnterEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#enterEvent

        **[override virtual protected] void QToolButton::enterEvent(QEnterEvent
        * e )**

        Reimplements: **QWidget::enterEvent** (QEnterEvent *event).
        """
        ...

    def actionEvent(self, a0: QtGui.QActionEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#actionEvent

        **[override virtual protected] void
        QToolButton::actionEvent(QActionEvent * event )**

        Reimplements: **QWidget::actionEvent** (QActionEvent *event).
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#paintEvent

        **[override virtual protected] void QToolButton::paintEvent(QPaintEvent
        * event )**

        Reimplements: **QAbstractButton::paintEvent** (QPaintEvent *e).

        Paints the button in response to the paint **event**.
        """
        ...

    def mousePressEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#mousePressEvent

        **[override virtual protected] void
        QToolButton::mousePressEvent(QMouseEvent * e )**

        Reimplements: **QAbstractButton::mousePressEvent** (QMouseEvent *e).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#event

        **[override virtual protected] bool QToolButton::event(QEvent * event
        )**

        Reimplements: **QAbstractButton::event** (QEvent *e).
        """
        ...

    def initStyleOption(self, option: QStyleOptionToolButton) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#initStyleOption

        **[virtual protected] void
        QToolButton::initStyleOption(QStyleOptionToolButton * option ) const**

        Initialize **option** with the values from this **QToolButton** . This
        method is useful for subclasses when they need a
        **QStyleOptionToolButton** , but don't want to fill in all the
        information themselves.

        **See also** **QStyleOption::initFrom** ().
        """
        ...

    def setDefaultAction(self, a0: QtGui.QAction) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#setDefaultAction

        **[slot] void QToolButton::setDefaultAction(QAction * action )**

        Sets the default action to **action**.

        If a tool button has a default action, the action defines the following
        properties of the button:

        * **checkable**
          * **checked**
          * **enabled**
          * **font**
          *
        **icon**
          * **popupMode**  (assuming the action has a menu)
          *
        **statusTip**
          * **text**
          * **toolTip**
          * **whatsThis**

        Other properties, such as **autoRepeat** , are not affected by actions.

        **See also** **defaultAction** ().
        """
        ...

    def setToolButtonStyle(self, style: QtCore.Qt.ToolButtonStyle) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#toolButtonStyle-prop

        **toolButtonStyle : Qt::ToolButtonStyle**

        This property holds whether the tool button displays an icon only, text
        only, or text beside/below the icon.

        The default is **Qt::ToolButtonIconOnly** .

        To have the style of toolbuttons follow the system settings, set this
        property to **Qt::ToolButtonFollowStyle** . On Unix, the user settings
        from the desktop environment will be used. On other platforms,
        **Qt::ToolButtonFollowStyle**  means icon only.

        **QToolButton**  automatically connects this slot to the relevant signal
        in the **QMainWindow**  in which is resides.

        **Access functions:**

        Qt::ToolButtonStyle **toolButtonStyle** () const
        void
        **setToolButtonStyle** (Qt::ToolButtonStyle **style** )

        **Member Function Documentation**
        """
        ...

    def showMenu(self) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#showMenu

        **[slot] void QToolButton::showMenu()**

        Shows (pops up) the associated popup menu. If there is no such menu,
        this function does nothing. This function does not return until the
        popup menu has been closed by the user.
        """
        ...

    def autoRaise(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#autoRaise-prop

        **autoRaise : bool**

        This property holds whether auto-raising is enabled or not.

        The default is disabled (i.e. false).

        This property is currently ignored on macOS when using QMacStyle.

        **Access functions:**

        bool **autoRaise** () const
        void **setAutoRaise** (bool **enable** )
        """
        ...

    def setAutoRaise(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#autoRaise-prop

        **autoRaise : bool**

        This property holds whether auto-raising is enabled or not.

        The default is disabled (i.e. false).

        This property is currently ignored on macOS when using QMacStyle.

        **Access functions:**

        bool **autoRaise** () const
        void **setAutoRaise** (bool **enable** )
        """
        ...

    def defaultAction(self) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#defaultAction

        **QAction *QToolButton::defaultAction() const**

        Returns the default action.

        **See also** **setDefaultAction** ().
        """
        ...

    def popupMode(self) -> "QToolButton.ToolButtonPopupMode":
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#popupMode-prop

        **popupMode : ToolButtonPopupMode**

        describes the way that popup menus are used with tool buttons

        By default, this property is set to **DelayedPopup** .

        **Access functions:**

        QToolButton::ToolButtonPopupMode **popupMode** () const
        void
        **setPopupMode** (QToolButton::ToolButtonPopupMode **mode** )
        """
        ...

    def setPopupMode(self, mode: "QToolButton.ToolButtonPopupMode") -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#popupMode-prop

        **popupMode : ToolButtonPopupMode**

        describes the way that popup menus are used with tool buttons

        By default, this property is set to **DelayedPopup** .

        **Access functions:**

        QToolButton::ToolButtonPopupMode **popupMode** () const
        void
        **setPopupMode** (QToolButton::ToolButtonPopupMode **mode** )
        """
        ...

    def menu(self) -> QMenu:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#menu

        **QMenu *QToolButton::menu() const**

        Returns the associated menu, or `nullptr` if no menu has been defined.

        **See also** **setMenu** ().
        """
        ...

    def setMenu(self, menu: QMenu) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#setMenu

        **void QToolButton::setMenu(QMenu * menu )**

        Associates the given **menu** with this tool button.

        The menu will be shown according to the button's **popupMode** .

        Ownership of the menu is not transferred to the tool button.

        **See also** **menu** ().
        """
        ...

    def setArrowType(self, type: QtCore.Qt.ArrowType) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#arrowType-prop

        **arrowType : Qt::ArrowType**

        This property holds whether the button displays an arrow instead of a
        normal icon

        This displays an arrow as the icon for the **QToolButton** .

        By default, this property is set to **Qt::NoArrow** .

        **Access functions:**

        Qt::ArrowType **arrowType** () const
        void **setArrowType**
        (Qt::ArrowType **type** )
        """
        ...

    def arrowType(self) -> QtCore.Qt.ArrowType:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#arrowType-prop

        **arrowType : Qt::ArrowType**

        This property holds whether the button displays an arrow instead of a
        normal icon

        This displays an arrow as the icon for the **QToolButton** .

        By default, this property is set to **Qt::NoArrow** .

        **Access functions:**

        Qt::ArrowType **arrowType** () const
        void **setArrowType**
        (Qt::ArrowType **type** )
        """
        ...

    def toolButtonStyle(self) -> QtCore.Qt.ToolButtonStyle:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#toolButtonStyle-prop

        **toolButtonStyle : Qt::ToolButtonStyle**

        This property holds whether the tool button displays an icon only, text
        only, or text beside/below the icon.

        The default is **Qt::ToolButtonIconOnly** .

        To have the style of toolbuttons follow the system settings, set this
        property to **Qt::ToolButtonFollowStyle** . On Unix, the user settings
        from the desktop environment will be used. On other platforms,
        **Qt::ToolButtonFollowStyle**  means icon only.

        **QToolButton**  automatically connects this slot to the relevant signal
        in the **QMainWindow**  in which is resides.

        **Access functions:**

        Qt::ToolButtonStyle **toolButtonStyle** () const
        void
        **setToolButtonStyle** (Qt::ToolButtonStyle **style** )

        **Member Function Documentation**
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#minimumSizeHint

        **[override virtual] QSize QToolButton::minimumSizeHint() const**

        Reimplements an access function for property:
        **QWidget::minimumSizeHint** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#sizeHint

        **[override virtual] QSize QToolButton::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...

    @property
    def triggered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtoolbutton.html#triggered

        **[signal] void QToolButton::triggered(QAction * action )**

        This signal is emitted when the given **action** is triggered.

        The action may also be associated with other parts of the user
        interface, such as menu items and keyboard shortcuts. Sharing actions in
        this way helps make the user interface more consistent and is often less
        work to implement.
        """
        ...
